// ##############################################################################
// Evolver with gaps and model of evolution. Not for distribution.
// Copyright Alex Nguyen Ba 2009
// Version 1.2
//
// LICENCE 
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.

// ##############################################################################

using namespace std;

#include <boost/regex.hpp>

#include <string>
#include <iostream>
#include <fstream>
#include <stdlib.h> 
#include <cstring>
#include <math.h>
#include <sstream>
#include <vector>

double P[26][26] = { 0 };
double P1[26][26] = { 0 };

double **P_structured = new double*[26];
double **P_disordered = new double*[26];

double **P1_structured = new double*[26];
double **P1_disordered = new double*[26];

double P_gap[2][2] = {0};
double P1_gap[2][2] = {0};

double *lambda_structured = new double[26];
double *lambda_disordered = new double[26];

double *lambda_gap = new double[2];

double * structured_sum_letters = new double[26];
double * disordered_sum_letters = new double[26];

//###############################################################################
// Symbols (Amino acids) Change to only ATCG if DNA will dramatically improve
// speed.
//###############################################################################

string aalist[20] = {"L","S","K","I","E","N","T","D","V","A","G","R","F","P","Q","Y","H","M","C","W"};
int aalist_size = sizeof(aalist)/sizeof(string);

string aalist_gap[2] = {"X","-"};
int aalist_size_gap = sizeof(aalist_gap)/sizeof(string);


class Sequence {
	
private:
	string m_seq_ID;
	string m_sequence;
public:
	
	//Constructor

	//Sequence(){
	//	m_seq_ID = NULL;
	//	m_sequence = NULL;
	//}
	
	//Setters
	bool appendLine(string seq_line){
		m_sequence += seq_line;
	}
	
	bool setHeader(string header){
		m_seq_ID = header;	
	}
	
	//Getters
	string getHeader(){
		return m_seq_ID;	
	}
	
	string getSequence(){
		return m_sequence;	
	}
};

class Genome {
private:
	int m_genome_size; //Number of sequences	
	map<int , Sequence*> list;
public:
	// Constructor
	Genome(){
		m_genome_size = -1;	
	}
	
	// Getter
	int getGenomeSize(){
		return m_genome_size+1;	
	}
	
	// Main function used.
	bool read_fasta(string fastafile){
		ifstream file;
		file.open(fastafile.c_str(),ifstream::in);
		int i =0;
		if (!file) return 0;
		string gene_name;
		string line;
		while (!file.fail()) {
			getline(file,line);
			if (line[0] == '>') {
				++m_genome_size;
				string header;
				header = "";
				for(int j = 1;j < line.length();j++){
					header += line[j];	
				}
				list[m_genome_size] = new Sequence;
				list[m_genome_size]->setHeader(header);
			}
			else{
				if(line.rfind("*")!=string::npos){
					line = line.erase(line.rfind("*"),1);	
				}
				if(line.rfind("\n")!=string::npos){
					line = line.erase(line.rfind("\n"),1);	
				}
				if(line.rfind("\r")!=string::npos){
					line = line.erase(line.rfind("\r"),1);	
				}
				//cout.flush();
				
				list[m_genome_size]->appendLine(line);
			}
		}
		
		return 1;	
	}
	
	// Grab a child sequence.
	Sequence getSequenceByID(int ID){
		return *list[ID];	
	}
	//Delete a child sequence
	void deleteSequenceByID(int ID){
		for(int i = ID;i < m_genome_size;++i){
			//delete[](list[i]);
			list[i] = list[i+1];
		}
		//delete[](list[m_genome_size]);
		list.erase(m_genome_size);
		m_genome_size -= 1;
	}
};

class doubleindex{
public:
	int incsize;
	double* data;
	doubleindex(int sizea, int sizeb){
		incsize = sizea;
		data = new double[sizea*sizeb];
		memset(data,'\0',sizeof(double)*sizea*sizeb);
	}
	~doubleindex(){
	}
	
	double read(int a, int b){return(data[a + b * incsize]);}
	void write(int a, int b, double in ){data[a + b * incsize] =in ;}
	double& operator()(int a, int b){
		return(data[a + b * incsize]);
	}
	
	void clear(){delete[](data);}

};

class singleindex{
public:
	double* data;
	singleindex(int sizea){
		data = new double[sizea];
		memset(data,'\0',sizeof(double)*sizea);
	}
	~singleindex(){
		
	}
	
	double read(int a){return(data[a]);}
	void write(int a, double in){data[a] = in;}
	double& operator()(int a){
		return(data[a]);	
	}
	
	void clear(){delete[](data);}
};
class Node{
private:
	string m_sequence;
	string m_node_ID;
	string m_disordered;
	bool is_parent;
	int child_1;
	int child_2;
	double distance_1;
	double distance_2;
	string species;
	vector<double> node_rate;
	vector<double> node_gap_rate;
	string m_phylo;
public:
	Node(){
		is_parent = 0;	
	}
	// Getters
	bool isParent(){
		return is_parent;	
	}
	int getChild_1(){
		return child_1;	
	}
	int getChild_2(){
		return child_2;	
	}
	double getDistance_1(){
		return distance_1;	
	}
	double getDistance_2(){
		return distance_2;	
	}
	double getRateAtPos(int pos){
		return node_rate[pos];
	}
	double getGapRateAtPos(int pos){
		return node_gap_rate[pos];
	}
	string getSpecie(){
		return species;	
	}
	// Setters
	bool appendLine(string seq_line){
		m_sequence += seq_line;
	}
	bool appendDisordered(string seq_line){
		m_disordered += seq_line;
	}
	bool appendPhylo(string seq_line){
		m_phylo += seq_line;
	}
	bool set_parent(){
		is_parent = 1;
	}
	bool set_child_1(int childID){
		child_1 = childID;	
	}
	bool set_child_2(int childID){
		child_2 = childID;	
	}
	bool set_distance_1(double d){
		distance_1 = d;	
	}
	bool set_distance_2(double d){
		distance_2 = d;	
	}
	bool set_rate(double *rate_ref,int length){
		node_rate.resize(length);
		for(int i = 0;i < length;++i){
			node_rate[i] = rate_ref[i];
		}
	}
	bool set_gap_rate(double *rate_ref,int length){
		node_gap_rate.resize(length);
		for(int i = 0;i < length;++i){
			node_gap_rate[i] = rate_ref[i];
		}
	}
	string getSequence(){
		return m_sequence;	
	}
	string getDisordered(){
		return m_disordered;
	}
	string getPhylo(){
		return m_phylo;
	}
	bool set_specie(string specie){
		species = specie;	
	}	
};
class NodeList{
private:
	int Nodelist_size;
	vector<Node*> list;
	
public:
	// Constructor
	NodeList(){
		Nodelist_size = -1;
	}
	
	bool createNode(){
		++Nodelist_size;
		list[Nodelist_size] = new Node;
	}
	bool resize_vector(int a){
		list.resize(2 * a); 
	}
	// Grab a node.
	Node getNodeByID(int ID){
		return *list[ID];	
	}
	
	// Getter
	int getNodeListSize(){
		return Nodelist_size+1;	
	}
	//
	void setSequenceOfNode(int ID,string seq){
		list[ID]->appendLine(seq);
	}
	void setDisordered(int ID,string seq){
		list[ID]->appendDisordered(seq);
	}
	//
	void setChildAsParent(int ID){
		list[ID]->set_parent();	
	}
	
	void setChild1(int ID,int childID){
		list[ID]->set_child_1(childID);	
	}
	void setChild2(int ID,int childID){
		list[ID]->set_child_2(childID);	
	}
	void setDistance1(int ID,double d){
		list[ID]->set_distance_1(d);	
	}
	void setDistance2(int ID,double d){
		list[ID]->set_distance_2(d);	
	}
	void setRateOfNode(int ID,double *rate_ref,int length){
		list[ID]->set_rate(rate_ref,length);
	}
	void setGapRateOfNode(int ID,double *rate_ref,int length){
		list[ID]->set_gap_rate(rate_ref,length);
	}
	void setPhylo(int ID,string seq){
		list[ID]->appendPhylo(seq);
	}
	void setSpeciebyID(int ID,string specie){
		list[ID]->set_specie(specie);	
	}
};

int count_in_string(string haystack, string needle){
	int count_in_string = 0;
	int i = 0;
	while(haystack.find(needle,i)!=string::npos){
		i = haystack.find(needle,i)+1;
		++count_in_string;
	}
	return count_in_string;
}
double sub_matrix3(char initial, char final,double distance_1,char disordered){
	
	double prob = 0;
	string letter;
	double lamb;
	if(disordered == '1'){
		for(int i = 0;i < aalist_size;++i){
			letter = aalist[i];
		
			lamb = exp(lambda_disordered[letter[0] - 'A'] * distance_1);
		
			prob += (P_disordered[initial - 'A'][letter[0] - 'A'] * lamb * P1_disordered[letter[0] - 'A'][final - 'A']);
		
		}
	}
	else{
		for(int i = 0;i < aalist_size;++i){
			letter = aalist[i];
		
			lamb = exp(lambda_structured[letter[0] - 'A'] * distance_1);
		
			prob += (P_structured[initial - 'A'][letter[0] - 'A'] * lamb * P1_structured[letter[0] - 'A'][final - 'A']);
		
		}
	}
	
	
	return prob;
}
double sub_matrix_gap(char initial, char final,double distance_1,double *p1){
	
	double prob= 0;
	string letter;
	double lamb;
	
	for(int i = 0;i < aalist_size_gap;++i){
		letter = aalist_gap[i];
		
		lamb = exp(lambda_gap[(int)(letter[0] - 88)/-43] * distance_1);
		
		prob += (P_gap[(int)(initial - 88)/-43][(int)(letter[0] - 88)/-43] * lamb * P1_gap[(int)(letter[0] - 88)/-43][(int)(final - 88)/-43]);
		
	}
	(*p1) = max(0.0,prob);
	
	
}
string help(){
	string helpstr;
	helpstr = "You are using Evolver_gap copyright Alex Nguyen Ba 2009\n";
	helpstr += "-length Specify the position to stop the algorithm in the gene.\n";
	helpstr += "-gap Specify if gaps are ignored.\n";
	return(helpstr);	
}
string convert(int number){
	ostringstream sin;
	sin << number;
	string val = sin.str();
	return(val);
}
string randomized(int slength,double *aa_prob){
	string return_string;
	for(int i = 0;i<slength;++i){
		// Case amino acid
		double random2 = 0;
		random2 = (double)rand()/RAND_MAX;
		while(random2 == 1){
			random2 = (double)rand()/RAND_MAX;
		}

		double rand_sum = 0;
		for(int j = 0;j<aalist_size;++j){
			rand_sum += aa_prob[(int)(aalist[j][0] - 'A')];
			if(rand_sum > random2){
				return_string += aalist[j];
				break;	
			}
		}
	}
	return return_string;
}

int main(int argc, char * argv[]) {
	
	// ##################################################
	// Usage
	// ##################################################
	
	cout.precision(20);
	int sim_length;
	double d_scale = 1;
	int conserved = 0;
	string inputs ("-l");
	string d_scales ("-d");
	string conserveds ("-c");
	string seeds ("-s");
	string ancestrals ("-anc");
	string rinputs ("-rinput");
	string gapcaps ("-gapcap");
	string trees ("-tree");
	int seed = 0;
	int ancestral_flag = 0;
	int disorder_flag = 0;
	string rinput;
	string treefile;

	int gapcap  = 0;
	for(int i = 1;i < argc;++i){
		if(argv[i] == ancestrals){
			ancestral_flag = 1;
		}
		if(argv[i] == inputs){
			sim_length = atoi(argv[i+1]);
		}
		if(argv[i] == d_scales){
			d_scale = atof(argv[i+1]);
		}
		if(argv[i] == conserveds){
			conserved = atoi(argv[i+1]);
		}
		if(argv[i] == trees){
			treefile = argv[i+1];	
		}
		if(argv[i] == seeds){
			seed = atoi(argv[i+1]);
		}
		if(argv[i] == rinputs){
			rinput = argv[i+1];
		}
		if(argv[i] == gapcaps){
			gapcap = 1;
		}
	}
	
	//###############################################################################
	// Rate map.
	//###############################################################################

	double * distance_dist;
	distance_dist = new double[sim_length];

	//double distance_dist[sim_length];
	memset(distance_dist,'\0',sizeof(double)*sim_length);
	boost::regex pattern;
	double * gap_dist;
	gap_dist = new double[sim_length];
	memset(gap_dist,'\0',sizeof(double)*sim_length);

	string disordered_ancestral;

	std::string::const_iterator start_tree, end_tree;
	std::string::const_iterator start_line, end_line;
	boost::match_results<std::string::const_iterator> what; 
	boost::match_results<std::string::const_iterator> what2; 
	
	pattern = "^([0-9]+)\\t([0-9\\.]+)\\t([0-9\\.]+)\\t([0-9\\.]+)\\t([0-9\\.]+)\\t([A-Z])";

	string ancestral;
	string phylo_hmm_pred;
	if(rinput == ""){
		cout << "Must have a distribution file (-rinput)" << endl;
		return 0;
	}
	else{
		ifstream file;
		file.open(rinput.c_str(),ifstream::in);
		if(!file) return 0;
		string line;
		while(!file.fail()){
			getline(file,line);
			start_line = line.begin(); 
			end_line = line.end();
			if(regex_search(start_line, end_line, what, pattern)) {
				string pos_dist = what[1];
				string pos_val = what[2];
				string pos_val2 = (what[3] < what[2]) ? what[3] : what[2];
				disordered_ancestral += what[4];
				phylo_hmm_pred += what[5];
				ancestral += what[6];
				distance_dist[atoi(pos_dist.c_str())-1] = atof(pos_val.c_str());
				gap_dist[atoi(pos_dist.c_str())-1] = atof(pos_val2.c_str());				
			}
			
		}
		file.close();
	}

	//###############################################################################
	// Phylogenetic tree in Newick format. 
	// Note, species not in this tree will not be parsed.
	// The tree will accomodate itself given the input file.
	// If the tree format is wrong, the code will likely fail.
	//###############################################################################
	
	ifstream file;
	file.open(treefile.c_str(),ifstream::in);
	if (!file){
		cout << "Can't find tree file." << endl;
		return 0;
	}
	string line = "";
	string tree = "";
	
	while(file >> line){
		tree += line;	
	}
	
	// Remove semi-colon.	
	if(tree.rfind(";")!=string::npos){
		tree = tree.erase(tree.rfind(";"),1);	
	}

	string print_tree = tree;
	
	//###############################################################################
	// Tree parsing
	// First step escapes all the tree_tags to regex format
	// All species in the tree will be used.
	// Last step fills parent array.
	//###############################################################################

	// Count the number of species
	start_tree = tree.begin(); 
	end_tree = tree.end();
	pattern = "[\\(,]{1}([^\\(\\)\\,\\:]+?):";
	int number_of_species = 0;
	
	while(regex_search(start_tree, end_tree, what, pattern)) { 
		string leaf = what[1];
		start_tree = what[1].second;
		
		++number_of_species;
		
	}
	string species_tree[number_of_species];
	string species_fasta[number_of_species];
	// Store the data
	start_tree = tree.begin(); 
	end_tree = tree.end();
	pattern = "[\\(,]{1}([^\\(\\)\\,\\:]+?):";
	int count = 0;
	while(regex_search(start_tree, end_tree, what, pattern)) { 
		string leaf = what[1];
		start_tree = what[1].second;
		
		species_fasta[count] = leaf;
		++count;
	}
	
	for(int i = 0;i < number_of_species;++i){
		if(species_fasta[i].length() == 0){
			species_fasta[i] = species_tree[i];	
		}
		if(species_tree[i].length() == 0){
			species_tree[i] = species_fasta[i];	
		}
	}

	boost::regex pattern2;
	
	NodeList nodes;	
	nodes.resize_vector(number_of_species);
	
	// Populate the tree leaves into node IDs.
	for(int j = 0;j<number_of_species;++j){
		pattern = species_tree[j];
		stringstream out;
		out << j;
		tree = regex_replace(tree,pattern,out.str());
		out.clear();
		
		nodes.createNode();
		nodes.setSpeciebyID(j,species_tree[j]);	
	}
	
	// Here we populate the nodes with IDs.
	int parent = number_of_species;
	int children_size = parent;
	
	start_tree = tree.begin(); 
	end_tree = tree.end();
	pattern = "\\(([0-9]*):([0-9\\.]*),([0-9]*):([0-9\\.]*)\\)";

	while(regex_search(start_tree, end_tree, what, pattern)) { 
		
		string child_1 = what[1];
		string child_2 = what[3];
		string distance_1 = what[2];
		string distance_2 = what[4];
		
		nodes.createNode();
		int node_ID = nodes.getNodeListSize()-1;
		nodes.setChildAsParent(node_ID);
	
		nodes.setChild1(node_ID,atoi(child_1.c_str()));
		nodes.setChild2(node_ID,atoi(child_2.c_str()));
		
		nodes.setDistance1(node_ID,d_scale * atof(distance_1.c_str()));
		nodes.setDistance2(node_ID,d_scale * atof(distance_2.c_str()));
		
		pattern2 = "(.*?)\\(([0-9:\\.]*),([0-9:\\.]*)\\)(.*)";
		stringstream out;
		out << parent;
		//tree = regex_replace(tree,pattern2,out.str());
		if(regex_search(start_tree,end_tree,what2,pattern2)){

			tree = what2[1] + out.str() + what2[4];	
		}
		out.clear();
		++parent;
				
		start_tree = tree.begin();
		end_tree = tree.end();
		//cout << tree << endl;
	}
	
	//######################################################################
	// Populate substitution matrix for the substitution model
	// We will hardcode the matrix instead.
	//######################################################################

	for(int i = 0;i < 26;++i){
		P_structured[i] = new double[26];
		P_disordered[i] = new double[26];
		P1_structured[i] = new double[26];
		P1_disordered[i] = new double[26];
	}
	
	lambda_structured[(int)('L' - 'A')] = -0.3214863;
	lambda_structured[(int)('S' - 'A')] = -0.2883979;
	lambda_structured[(int)('K' - 'A')] = -0.2600245;
	lambda_structured[(int)('I' - 'A')] = -0.2344791;
	lambda_structured[(int)('E' - 'A')] = -0.1954271;
	lambda_structured[(int)('N' - 'A')] = -0.1841992;
	lambda_structured[(int)('T' - 'A')] = -0.1593952;
	lambda_structured[(int)('D' - 'A')] = -0.1471261;
	lambda_structured[(int)('V' - 'A')] = -0.1348377;
	lambda_structured[(int)('A' - 'A')] = -0.1305218;
	lambda_structured[(int)('G' - 'A')] = -0.1132155;
	lambda_structured[(int)('R' - 'A')] = -0.1035203;
	lambda_structured[(int)('F' - 'A')] = -0.09636403;
	lambda_structured[(int)('P' - 'A')] = -0.09033717;
	lambda_structured[(int)('Q' - 'A')] = -0.08312976;
	lambda_structured[(int)('Y' - 'A')] = -0.05583822;
	lambda_structured[(int)('H' - 'A')] = -0.04784859;
	lambda_structured[(int)('M' - 'A')] = -0.04019728;
	lambda_structured[(int)('C' - 'A')] = -0.01144137;
	lambda_structured[(int)('W' - 'A')] = 0;


	lambda_disordered[(int)('L' - 'A')] = -0.359673;
	lambda_disordered[(int)('S' - 'A')] = -0.3064377;
	lambda_disordered[(int)('K' - 'A')] = -0.2804928;
	lambda_disordered[(int)('I' - 'A')] = -0.2418725;
	lambda_disordered[(int)('E' - 'A')] = -0.2321626;
	lambda_disordered[(int)('N' - 'A')] = -0.2098799;
	lambda_disordered[(int)('T' - 'A')] = -0.1738147;
	lambda_disordered[(int)('D' - 'A')] = -0.1615333;
	lambda_disordered[(int)('V' - 'A')] = -0.1362382;
	lambda_disordered[(int)('A' - 'A')] = -0.1244042;
	lambda_disordered[(int)('G' - 'A')] = -0.1184668;
	lambda_disordered[(int)('R' - 'A')] = -0.1181359;
	lambda_disordered[(int)('F' - 'A')] = -0.1068279;
	lambda_disordered[(int)('P' - 'A')] = -0.09347767;
	lambda_disordered[(int)('Q' - 'A')] = -0.07037878;
	lambda_disordered[(int)('Y' - 'A')] = -0.06262095;
	lambda_disordered[(int)('H' - 'A')] = -0.05216432;
	lambda_disordered[(int)('M' - 'A')] = -0.03915904;
	lambda_disordered[(int)('C' - 'A')] = -0.009870964;
	lambda_disordered[(int)('W' - 'A')] = 0;

		
	P_structured[(int)('L' - 'A')][(int)('L' - 'A')] = 0.002892364;	P_structured[(int)('L' - 'A')][(int)('S' - 'A')] = -0.057803264;	P_structured[(int)('L' - 'A')][(int)('K' - 'A')] = -0.007213978;	P_structured[(int)('L' - 'A')][(int)('I' - 'A')] = -0.04537172;	P_structured[(int)('L' - 'A')][(int)('E' - 'A')] = -0.004700298;	P_structured[(int)('L' - 'A')][(int)('N' - 'A')] = 0.099027557;	P_structured[(int)('L' - 'A')][(int)('T' - 'A')] = -0.185725603;	P_structured[(int)('L' - 'A')][(int)('D' - 'A')] = 0.244352764;	P_structured[(int)('L' - 'A')][(int)('V' - 'A')] = -0.345693726;	P_structured[(int)('L' - 'A')][(int)('A' - 'A')] = -0.1196115078;	P_structured[(int)('L' - 'A')][(int)('G' - 'A')] = 0.0730289;	P_structured[(int)('L' - 'A')][(int)('R' - 'A')] = -0.041169897;	P_structured[(int)('L' - 'A')][(int)('F' - 'A')] = 0.0284116975;	P_structured[(int)('L' - 'A')][(int)('P' - 'A')] = -0.010548805;	P_structured[(int)('L' - 'A')][(int)('Q' - 'A')] = -0.12916082;	P_structured[(int)('L' - 'A')][(int)('Y' - 'A')] = 0.002258741;	P_structured[(int)('L' - 'A')][(int)('H' - 'A')] = 0.24921394;	P_structured[(int)('L' - 'A')][(int)('M' - 'A')] = -0.10182551;	P_structured[(int)('L' - 'A')][(int)('C' - 'A')] = -0.008151367;	P_structured[(int)('L' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('S' - 'A')][(int)('L' - 'A')] = -0.0001510547;	P_structured[(int)('S' - 'A')][(int)('S' - 'A')] = 0.697110251;	P_structured[(int)('S' - 'A')][(int)('K' - 'A')] = 0.03672249;	P_structured[(int)('S' - 'A')][(int)('I' - 'A')] = 0.344215273;	P_structured[(int)('S' - 'A')][(int)('E' - 'A')] = 0.013492984;	P_structured[(int)('S' - 'A')][(int)('N' - 'A')] = -0.04814501;	P_structured[(int)('S' - 'A')][(int)('T' - 'A')] = -0.305393079;	P_structured[(int)('S' - 'A')][(int)('D' - 'A')] = 0.006971367;	P_structured[(int)('S' - 'A')][(int)('V' - 'A')] = 0.0564147875;	P_structured[(int)('S' - 'A')][(int)('A' - 'A')] = 0.0491728829;	P_structured[(int)('S' - 'A')][(int)('G' - 'A')] = -0.06205012;	P_structured[(int)('S' - 'A')][(int)('R' - 'A')] = 0.038071712;	P_structured[(int)('S' - 'A')][(int)('F' - 'A')] = -0.1386360945;	P_structured[(int)('S' - 'A')][(int)('P' - 'A')] = -0.019145128;	P_structured[(int)('S' - 'A')][(int)('Q' - 'A')] = 0.12986175;	P_structured[(int)('S' - 'A')][(int)('Y' - 'A')] = 0.02477718;	P_structured[(int)('S' - 'A')][(int)('H' - 'A')] = 0.02492222;	P_structured[(int)('S' - 'A')][(int)('M' - 'A')] = 0.03410245;	P_structured[(int)('S' - 'A')][(int)('C' - 'A')] = -0.013473816;	P_structured[(int)('S' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('K' - 'A')][(int)('L' - 'A')] = -0.001830552;	P_structured[(int)('K' - 'A')][(int)('S' - 'A')] = 0.108703394;	P_structured[(int)('K' - 'A')][(int)('K' - 'A')] = -0.04943516;	P_structured[(int)('K' - 'A')][(int)('I' - 'A')] = -0.282586131;	P_structured[(int)('K' - 'A')][(int)('E' - 'A')] = 0.559629006;	P_structured[(int)('K' - 'A')][(int)('N' - 'A')] = 0.068721022;	P_structured[(int)('K' - 'A')][(int)('T' - 'A')] = -0.003647083;	P_structured[(int)('K' - 'A')][(int)('D' - 'A')] = 0.004387626;	P_structured[(int)('K' - 'A')][(int)('V' - 'A')] = 0.0083438031;	P_structured[(int)('K' - 'A')][(int)('A' - 'A')] = -0.082855073;	P_structured[(int)('K' - 'A')][(int)('G' - 'A')] = -0.1338531;	P_structured[(int)('K' - 'A')][(int)('R' - 'A')] = 0.24699223;	P_structured[(int)('K' - 'A')][(int)('F' - 'A')] = 0.1296964837;	P_structured[(int)('K' - 'A')][(int)('P' - 'A')] = -0.002824393;	P_structured[(int)('K' - 'A')][(int)('Q' - 'A')] = -0.23004038;	P_structured[(int)('K' - 'A')][(int)('Y' - 'A')] = -0.032913435;	P_structured[(int)('K' - 'A')][(int)('H' - 'A')] = -0.18334795;	P_structured[(int)('K' - 'A')][(int)('M' - 'A')] = 0.18755469;	P_structured[(int)('K' - 'A')][(int)('C' - 'A')] = -0.015350847;	P_structured[(int)('K' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('I' - 'A')][(int)('L' - 'A')] = -0.5740978;	P_structured[(int)('I' - 'A')][(int)('S' - 'A')] = 0.022851853;	P_structured[(int)('I' - 'A')][(int)('K' - 'A')] = -0.1190872;	P_structured[(int)('I' - 'A')][(int)('I' - 'A')] = 0.112356163;	P_structured[(int)('I' - 'A')][(int)('E' - 'A')] = 0.066760897;	P_structured[(int)('I' - 'A')][(int)('N' - 'A')] = -0.235928698;	P_structured[(int)('I' - 'A')][(int)('T' - 'A')] = 0.327104761;	P_structured[(int)('I' - 'A')][(int)('D' - 'A')] = 0.030801397;	P_structured[(int)('I' - 'A')][(int)('V' - 'A')] = 0.1792577926;	P_structured[(int)('I' - 'A')][(int)('A' - 'A')] = 0.0316988897;	P_structured[(int)('I' - 'A')][(int)('G' - 'A')] = 0.009766645;	P_structured[(int)('I' - 'A')][(int)('R' - 'A')] = -0.034661981;	P_structured[(int)('I' - 'A')][(int)('F' - 'A')] = 0.2141905996;	P_structured[(int)('I' - 'A')][(int)('P' - 'A')] = -0.133859888;	P_structured[(int)('I' - 'A')][(int)('Q' - 'A')] = 0.03889756;	P_structured[(int)('I' - 'A')][(int)('Y' - 'A')] = 0.010557893;	P_structured[(int)('I' - 'A')][(int)('H' - 'A')] = 0.2438412;	P_structured[(int)('I' - 'A')][(int)('M' - 'A')] = -0.0321946;	P_structured[(int)('I' - 'A')][(int)('C' - 'A')] = -0.013361537;	P_structured[(int)('I' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('E' - 'A')][(int)('L' - 'A')] = -0.0100958;	P_structured[(int)('E' - 'A')][(int)('S' - 'A')] = -0.066914882;	P_structured[(int)('E' - 'A')][(int)('K' - 'A')] = 0.07500563;	P_structured[(int)('E' - 'A')][(int)('I' - 'A')] = 0.43643775;	P_structured[(int)('E' - 'A')][(int)('E' - 'A')] = 0.006367897;	P_structured[(int)('E' - 'A')][(int)('N' - 'A')] = 0.508251193;	P_structured[(int)('E' - 'A')][(int)('T' - 'A')] = 0.290460313;	P_structured[(int)('E' - 'A')][(int)('D' - 'A')] = 0.002422125;	P_structured[(int)('E' - 'A')][(int)('V' - 'A')] = 0.0268686208;	P_structured[(int)('E' - 'A')][(int)('A' - 'A')] = -0.278778563;	P_structured[(int)('E' - 'A')][(int)('G' - 'A')] = 0.1988395;	P_structured[(int)('E' - 'A')][(int)('R' - 'A')] = -0.082449047;	P_structured[(int)('E' - 'A')][(int)('F' - 'A')] = 0.0725011206;	P_structured[(int)('E' - 'A')][(int)('P' - 'A')] = 0.21554183;	P_structured[(int)('E' - 'A')][(int)('Q' - 'A')] = 0.07223929;	P_structured[(int)('E' - 'A')][(int)('Y' - 'A')] = -0.030352211;	P_structured[(int)('E' - 'A')][(int)('H' - 'A')] = -0.17463;	P_structured[(int)('E' - 'A')][(int)('M' - 'A')] = 0.19245941;	P_structured[(int)('E' - 'A')][(int)('C' - 'A')] = -0.016715551;	P_structured[(int)('E' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('N' - 'A')][(int)('L' - 'A')] = 0.002569941;	P_structured[(int)('N' - 'A')][(int)('S' - 'A')] = -0.553434512;	P_structured[(int)('N' - 'A')][(int)('K' - 'A')] = 0.3480017;	P_structured[(int)('N' - 'A')][(int)('I' - 'A')] = 0.314200786;	P_structured[(int)('N' - 'A')][(int)('E' - 'A')] = 0.174074721;	P_structured[(int)('N' - 'A')][(int)('N' - 'A')] = -0.470226812;	P_structured[(int)('N' - 'A')][(int)('T' - 'A')] = -0.371999299;	P_structured[(int)('N' - 'A')][(int)('D' - 'A')] = 0.005181966;	P_structured[(int)('N' - 'A')][(int)('V' - 'A')] = 0.0880992872;	P_structured[(int)('N' - 'A')][(int)('A' - 'A')] = -0.1233406449;	P_structured[(int)('N' - 'A')][(int)('G' - 'A')] = -0.09010394;	P_structured[(int)('N' - 'A')][(int)('R' - 'A')] = -0.042001158;	P_structured[(int)('N' - 'A')][(int)('F' - 'A')] = -0.0274802081;	P_structured[(int)('N' - 'A')][(int)('P' - 'A')] = 0.066689717;	P_structured[(int)('N' - 'A')][(int)('Q' - 'A')] = 0.12309432;	P_structured[(int)('N' - 'A')][(int)('Y' - 'A')] = -0.008169956;	P_structured[(int)('N' - 'A')][(int)('H' - 'A')] = -0.09818324;	P_structured[(int)('N' - 'A')][(int)('M' - 'A')] = 0.10831249;	P_structured[(int)('N' - 'A')][(int)('C' - 'A')] = -0.015810255;	P_structured[(int)('N' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('T' - 'A')][(int)('L' - 'A')] = 0.178174;	P_structured[(int)('T' - 'A')][(int)('S' - 'A')] = -0.32665627;	P_structured[(int)('T' - 'A')][(int)('K' - 'A')] = -0.7216632;	P_structured[(int)('T' - 'A')][(int)('I' - 'A')] = 0.073277953;	P_structured[(int)('T' - 'A')][(int)('E' - 'A')] = -0.060352932;	P_structured[(int)('T' - 'A')][(int)('N' - 'A')] = 0.238729451;	P_structured[(int)('T' - 'A')][(int)('T' - 'A')] = -0.30176182;	P_structured[(int)('T' - 'A')][(int)('D' - 'A')] = -0.041146554;	P_structured[(int)('T' - 'A')][(int)('V' - 'A')] = 0.2780506523;	P_structured[(int)('T' - 'A')][(int)('A' - 'A')] = 0.1109243155;	P_structured[(int)('T' - 'A')][(int)('G' - 'A')] = -0.07630442;	P_structured[(int)('T' - 'A')][(int)('R' - 'A')] = 0.047050563;	P_structured[(int)('T' - 'A')][(int)('F' - 'A')] = -0.0068122572;	P_structured[(int)('T' - 'A')][(int)('P' - 'A')] = -0.087943815;	P_structured[(int)('T' - 'A')][(int)('Q' - 'A')] = 0.14367097;	P_structured[(int)('T' - 'A')][(int)('Y' - 'A')] = 0.01393969;	P_structured[(int)('T' - 'A')][(int)('H' - 'A')] = 0.0891594;	P_structured[(int)('T' - 'A')][(int)('M' - 'A')] = 0.04678191;	P_structured[(int)('T' - 'A')][(int)('C' - 'A')] = -0.01473938;	P_structured[(int)('T' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('D' - 'A')][(int)('L' - 'A')] = -0.0008840247;	P_structured[(int)('D' - 'A')][(int)('S' - 'A')] = 0.18528506;	P_structured[(int)('D' - 'A')][(int)('K' - 'A')] = -0.1988526;	P_structured[(int)('D' - 'A')][(int)('I' - 'A')] = -0.508830548;	P_structured[(int)('D' - 'A')][(int)('E' - 'A')] = -0.283363459;	P_structured[(int)('D' - 'A')][(int)('N' - 'A')] = -0.316473776;	P_structured[(int)('D' - 'A')][(int)('T' - 'A')] = -0.01599891;	P_structured[(int)('D' - 'A')][(int)('D' - 'A')] = 0.014964356;	P_structured[(int)('D' - 'A')][(int)('V' - 'A')] = 0.0275731448;	P_structured[(int)('D' - 'A')][(int)('A' - 'A')] = -0.3600721413;	P_structured[(int)('D' - 'A')][(int)('G' - 'A')] = 0.08571507;	P_structured[(int)('D' - 'A')][(int)('R' - 'A')] = -0.155494019;	P_structured[(int)('D' - 'A')][(int)('F' - 'A')] = 0.0279266874;	P_structured[(int)('D' - 'A')][(int)('P' - 'A')] = 0.253436058;	P_structured[(int)('D' - 'A')][(int)('Q' - 'A')] = 0.21583495;	P_structured[(int)('D' - 'A')][(int)('Y' - 'A')] = -0.020946551;	P_structured[(int)('D' - 'A')][(int)('H' - 'A')] = -0.15867011;	P_structured[(int)('D' - 'A')][(int)('M' - 'A')] = 0.16648556;	P_structured[(int)('D' - 'A')][(int)('C' - 'A')] = -0.016866482;	P_structured[(int)('D' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('V' - 'A')][(int)('L' - 'A')] = 0.7524656;	P_structured[(int)('V' - 'A')][(int)('S' - 'A')] = 0.065135731;	P_structured[(int)('V' - 'A')][(int)('K' - 'A')] = 0.1899258;	P_structured[(int)('V' - 'A')][(int)('I' - 'A')] = -0.040361196;	P_structured[(int)('V' - 'A')][(int)('E' - 'A')] = 0.018040717;	P_structured[(int)('V' - 'A')][(int)('N' - 'A')] = -0.121831157;	P_structured[(int)('V' - 'A')][(int)('T' - 'A')] = 0.30892629;	P_structured[(int)('V' - 'A')][(int)('D' - 'A')] = 0.046693725;	P_structured[(int)('V' - 'A')][(int)('V' - 'A')] = 0.208819821;	P_structured[(int)('V' - 'A')][(int)('A' - 'A')] = 0.0610077821;	P_structured[(int)('V' - 'A')][(int)('G' - 'A')] = 0.00951705;	P_structured[(int)('V' - 'A')][(int)('R' - 'A')] = -0.032316064;	P_structured[(int)('V' - 'A')][(int)('F' - 'A')] = 0.1891090843;	P_structured[(int)('V' - 'A')][(int)('P' - 'A')] = -0.122808618;	P_structured[(int)('V' - 'A')][(int)('Q' - 'A')] = 0.06419045;	P_structured[(int)('V' - 'A')][(int)('Y' - 'A')] = 0.010983914;	P_structured[(int)('V' - 'A')][(int)('H' - 'A')] = 0.22643473;	P_structured[(int)('V' - 'A')][(int)('M' - 'A')] = -0.0198868;	P_structured[(int)('V' - 'A')][(int)('C' - 'A')] = -0.013512361;	P_structured[(int)('V' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('A' - 'A')][(int)('L' - 'A')] = -0.2657967;	P_structured[(int)('A' - 'A')][(int)('S' - 'A')] = -0.081379074;	P_structured[(int)('A' - 'A')][(int)('K' - 'A')] = 0.4982255;	P_structured[(int)('A' - 'A')][(int)('I' - 'A')] = -0.432715922;	P_structured[(int)('A' - 'A')][(int)('E' - 'A')] = -0.187891753;	P_structured[(int)('A' - 'A')][(int)('N' - 'A')] = 0.446085223;	P_structured[(int)('A' - 'A')][(int)('T' - 'A')] = -0.198527224;	P_structured[(int)('A' - 'A')][(int)('D' - 'A')] = -0.018628721;	P_structured[(int)('A' - 'A')][(int)('V' - 'A')] = 0.2840831328;	P_structured[(int)('A' - 'A')][(int)('A' - 'A')] = 0.1796159803;	P_structured[(int)('A' - 'A')][(int)('G' - 'A')] = -0.0536515;	P_structured[(int)('A' - 'A')][(int)('R' - 'A')] = 0.030916037;	P_structured[(int)('A' - 'A')][(int)('F' - 'A')] = -0.0227258111;	P_structured[(int)('A' - 'A')][(int)('P' - 'A')] = -0.074932362;	P_structured[(int)('A' - 'A')][(int)('Q' - 'A')] = 0.18373745;	P_structured[(int)('A' - 'A')][(int)('Y' - 'A')] = 0.015483813;	P_structured[(int)('A' - 'A')][(int)('H' - 'A')] = 0.09826151;	P_structured[(int)('A' - 'A')][(int)('M' - 'A')] = 0.0478352;	P_structured[(int)('A' - 'A')][(int)('C' - 'A')] = -0.014894454;	P_structured[(int)('A' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('G' - 'A')][(int)('L' - 'A')] = 0.003387606;	P_structured[(int)('G' - 'A')][(int)('S' - 'A')] = -0.068355497;	P_structured[(int)('G' - 'A')][(int)('K' - 'A')] = -0.05403676;	P_structured[(int)('G' - 'A')][(int)('I' - 'A')] = -0.037679009;	P_structured[(int)('G' - 'A')][(int)('E' - 'A')] = 0.08887879;	P_structured[(int)('G' - 'A')][(int)('N' - 'A')] = -0.038180069;	P_structured[(int)('G' - 'A')][(int)('T' - 'A')] = 0.207768161;	P_structured[(int)('G' - 'A')][(int)('D' - 'A')] = -0.014618113;	P_structured[(int)('G' - 'A')][(int)('V' - 'A')] = -0.4788265571;	P_structured[(int)('G' - 'A')][(int)('A' - 'A')] = 0.6306153201;	P_structured[(int)('G' - 'A')][(int)('G' - 'A')] = -0.08770642;	P_structured[(int)('G' - 'A')][(int)('R' - 'A')] = -0.078565346;	P_structured[(int)('G' - 'A')][(int)('F' - 'A')] = -0.0209646021;	P_structured[(int)('G' - 'A')][(int)('P' - 'A')] = 0.229215231;	P_structured[(int)('G' - 'A')][(int)('Q' - 'A')] = 0.30111758;	P_structured[(int)('G' - 'A')][(int)('Y' - 'A')] = 0.005029366;	P_structured[(int)('G' - 'A')][(int)('H' - 'A')] = -0.09737966;	P_structured[(int)('G' - 'A')][(int)('M' - 'A')] = 0.14753542;	P_structured[(int)('G' - 'A')][(int)('C' - 'A')] = -0.015512556;	P_structured[(int)('G' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('R' - 'A')][(int)('L' - 'A')] = 0.001049391;	P_structured[(int)('R' - 'A')][(int)('S' - 'A')] = -0.058918994;	P_structured[(int)('R' - 'A')][(int)('K' - 'A')] = 0.03823914;	P_structured[(int)('R' - 'A')][(int)('I' - 'A')] = 0.175461726;	P_structured[(int)('R' - 'A')][(int)('E' - 'A')] = -0.714404134;	P_structured[(int)('R' - 'A')][(int)('N' - 'A')] = -0.100239468;	P_structured[(int)('R' - 'A')][(int)('T' - 'A')] = 0.126480234;	P_structured[(int)('R' - 'A')][(int)('D' - 'A')] = 0.045040037;	P_structured[(int)('R' - 'A')][(int)('V' - 'A')] = -0.1235533444;	P_structured[(int)('R' - 'A')][(int)('A' - 'A')] = 0.0513320229;	P_structured[(int)('R' - 'A')][(int)('G' - 'A')] = -0.2937686;	P_structured[(int)('R' - 'A')][(int)('R' - 'A')] = 0.320431713;	P_structured[(int)('R' - 'A')][(int)('F' - 'A')] = 0.1230302674;	P_structured[(int)('R' - 'A')][(int)('P' - 'A')] = -0.099437093;	P_structured[(int)('R' - 'A')][(int)('Q' - 'A')] = -0.36821992;	P_structured[(int)('R' - 'A')][(int)('Y' - 'A')] = -0.030158434;	P_structured[(int)('R' - 'A')][(int)('H' - 'A')] = -0.2067524;	P_structured[(int)('R' - 'A')][(int)('M' - 'A')] = 0.17358948;	P_structured[(int)('R' - 'A')][(int)('C' - 'A')] = -0.012727655;	P_structured[(int)('R' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('F' - 'A')][(int)('L' - 'A')] = 0.0025109;	P_structured[(int)('F' - 'A')][(int)('S' - 'A')] = -0.020166703;	P_structured[(int)('F' - 'A')][(int)('K' - 'A')] = 0.0002037378;	P_structured[(int)('F' - 'A')][(int)('I' - 'A')] = -0.00982192;	P_structured[(int)('F' - 'A')][(int)('E' - 'A')] = -0.001003129;	P_structured[(int)('F' - 'A')][(int)('N' - 'A')] = -0.01924099;	P_structured[(int)('F' - 'A')][(int)('T' - 'A')] = 0.086059842;	P_structured[(int)('F' - 'A')][(int)('D' - 'A')] = -0.151980579;	P_structured[(int)('F' - 'A')][(int)('V' - 'A')] = 0.208940636;	P_structured[(int)('F' - 'A')][(int)('A' - 'A')] = 0.0755515766;	P_structured[(int)('F' - 'A')][(int)('G' - 'A')] = -0.1120621;	P_structured[(int)('F' - 'A')][(int)('R' - 'A')] = -0.010574745;	P_structured[(int)('F' - 'A')][(int)('F' - 'A')] = -0.2254732778;	P_structured[(int)('F' - 'A')][(int)('P' - 'A')] = 0.574378542;	P_structured[(int)('F' - 'A')][(int)('Q' - 'A')] = -0.34695077;	P_structured[(int)('F' - 'A')][(int)('Y' - 'A')] = -0.04870982;	P_structured[(int)('F' - 'A')][(int)('H' - 'A')] = 0.165397;	P_structured[(int)('F' - 'A')][(int)('M' - 'A')] = -0.35097914;	P_structured[(int)('F' - 'A')][(int)('C' - 'A')] = -0.010001375;	P_structured[(int)('F' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('P' - 'A')][(int)('L' - 'A')] = 0.003824378;	P_structured[(int)('P' - 'A')][(int)('S' - 'A')] = -0.148386789;	P_structured[(int)('P' - 'A')][(int)('K' - 'A')] = -0.01374969;	P_structured[(int)('P' - 'A')][(int)('I' - 'A')] = -0.078410079;	P_structured[(int)('P' - 'A')][(int)('E' - 'A')] = 0.038609488;	P_structured[(int)('P' - 'A')][(int)('N' - 'A')] = -0.075739345;	P_structured[(int)('P' - 'A')][(int)('T' - 'A')] = 0.386256807;	P_structured[(int)('P' - 'A')][(int)('D' - 'A')] = -0.081352391;	P_structured[(int)('P' - 'A')][(int)('V' - 'A')] = -0.1376309426;	P_structured[(int)('P' - 'A')][(int)('A' - 'A')] = -0.2270965513;	P_structured[(int)('P' - 'A')][(int)('G' - 'A')] = 0.09899314;	P_structured[(int)('P' - 'A')][(int)('R' - 'A')] = 0.275992948;	P_structured[(int)('P' - 'A')][(int)('F' - 'A')] = -0.7512503566;	P_structured[(int)('P' - 'A')][(int)('P' - 'A')] = -0.292363602;	P_structured[(int)('P' - 'A')][(int)('Q' - 'A')] = 0.16404303;	P_structured[(int)('P' - 'A')][(int)('Y' - 'A')] = 0.020321827;	P_structured[(int)('P' - 'A')][(int)('H' - 'A')] = 0.10479127;	P_structured[(int)('P' - 'A')][(int)('M' - 'A')] = 0.02465362;	P_structured[(int)('P' - 'A')][(int)('C' - 'A')] = -0.014248421;	P_structured[(int)('P' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('Q' - 'A')][(int)('L' - 'A')] = 0.00003607738;	P_structured[(int)('Q' - 'A')][(int)('S' - 'A')] = 0.00382885;	P_structured[(int)('Q' - 'A')][(int)('K' - 'A')] = -0.00901388;	P_structured[(int)('Q' - 'A')][(int)('I' - 'A')] = -0.047163452;	P_structured[(int)('Q' - 'A')][(int)('E' - 'A')] = -0.044492279;	P_structured[(int)('Q' - 'A')][(int)('N' - 'A')] = -0.172132235;	P_structured[(int)('Q' - 'A')][(int)('T' - 'A')] = -0.157486111;	P_structured[(int)('Q' - 'A')][(int)('D' - 'A')] = -0.056069321;	P_structured[(int)('Q' - 'A')][(int)('V' - 'A')] = 0.1531283551;	P_structured[(int)('Q' - 'A')][(int)('A' - 'A')] = 0.4193679425;	P_structured[(int)('Q' - 'A')][(int)('G' - 'A')] = 0.6849328;	P_structured[(int)('Q' - 'A')][(int)('R' - 'A')] = -0.128916053;	P_structured[(int)('Q' - 'A')][(int)('F' - 'A')] = -0.1139812726;	P_structured[(int)('Q' - 'A')][(int)('P' - 'A')] = -0.190281436;	P_structured[(int)('Q' - 'A')][(int)('Q' - 'A')] = -0.47627962;	P_structured[(int)('Q' - 'A')][(int)('Y' - 'A')] = -0.056987224;	P_structured[(int)('Q' - 'A')][(int)('H' - 'A')] = -0.20862198;	P_structured[(int)('Q' - 'A')][(int)('M' - 'A')] = 0.16200499;	P_structured[(int)('Q' - 'A')][(int)('C' - 'A')] = -0.014767637;	P_structured[(int)('Q' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('Y' - 'A')][(int)('L' - 'A')] = 0.0001701702;	P_structured[(int)('Y' - 'A')][(int)('S' - 'A')] = -0.003804815;	P_structured[(int)('Y' - 'A')][(int)('K' - 'A')] = -0.003323957;	P_structured[(int)('Y' - 'A')][(int)('I' - 'A')] = -0.006171887;	P_structured[(int)('Y' - 'A')][(int)('E' - 'A')] = -0.002226063;	P_structured[(int)('Y' - 'A')][(int)('N' - 'A')] = 0.010186178;	P_structured[(int)('Y' - 'A')][(int)('T' - 'A')] = -0.002069599;	P_structured[(int)('Y' - 'A')][(int)('D' - 'A')] = 0.025488787;	P_structured[(int)('Y' - 'A')][(int)('V' - 'A')] = -0.0452916676;	P_structured[(int)('Y' - 'A')][(int)('A' - 'A')] = 0.0011344473;	P_structured[(int)('Y' - 'A')][(int)('G' - 'A')] = 0.105845;	P_structured[(int)('Y' - 'A')][(int)('R' - 'A')] = 0.136059584;	P_structured[(int)('Y' - 'A')][(int)('F' - 'A')] = 0.1518444089;	P_structured[(int)('Y' - 'A')][(int)('P' - 'A')] = -0.171655516;	P_structured[(int)('Y' - 'A')][(int)('Q' - 'A')] = 0.2646846;	P_structured[(int)('Y' - 'A')][(int)('Y' - 'A')] = -0.212066418;	P_structured[(int)('Y' - 'A')][(int)('H' - 'A')] = -0.4760799;	P_structured[(int)('Y' - 'A')][(int)('M' - 'A')] = -0.73140448;	P_structured[(int)('Y' - 'A')][(int)('C' - 'A')] = -0.01159149;	P_structured[(int)('Y' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('H' - 'A')][(int)('L' - 'A')] = 0.00001957728;	P_structured[(int)('H' - 'A')][(int)('S' - 'A')] = 0.040309163;	P_structured[(int)('H' - 'A')][(int)('K' - 'A')] = -0.03452997;	P_structured[(int)('H' - 'A')][(int)('I' - 'A')] = -0.046422837;	P_structured[(int)('H' - 'A')][(int)('E' - 'A')] = 0.082992064;	P_structured[(int)('H' - 'A')][(int)('N' - 'A')] = 0.16487341;	P_structured[(int)('H' - 'A')][(int)('T' - 'A')] = 0.150718098;	P_structured[(int)('H' - 'A')][(int)('D' - 'A')] = -0.024763193;	P_structured[(int)('H' - 'A')][(int)('V' - 'A')] = -0.0133518145;	P_structured[(int)('H' - 'A')][(int)('A' - 'A')] = -0.0827500809;	P_structured[(int)('H' - 'A')][(int)('G' - 'A')] = -0.5521474;	P_structured[(int)('H' - 'A')][(int)('R' - 'A')] = -0.821665724;	P_structured[(int)('H' - 'A')][(int)('F' - 'A')] = -0.2800539754;	P_structured[(int)('H' - 'A')][(int)('P' - 'A')] = -0.500636851;	P_structured[(int)('H' - 'A')][(int)('Q' - 'A')] = -0.32245329;	P_structured[(int)('H' - 'A')][(int)('Y' - 'A')] = -0.09078424;	P_structured[(int)('H' - 'A')][(int)('H' - 'A')] = -0.30315893;	P_structured[(int)('H' - 'A')][(int)('M' - 'A')] = -0.04699198;	P_structured[(int)('H' - 'A')][(int)('C' - 'A')] = -0.014792937;	P_structured[(int)('H' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('M' - 'A')][(int)('L' - 'A')] = 0.04072508;	P_structured[(int)('M' - 'A')][(int)('S' - 'A')] = 0.022003678;	P_structured[(int)('M' - 'A')][(int)('K' - 'A')] = 0.06867893;	P_structured[(int)('M' - 'A')][(int)('I' - 'A')] = -0.009676032;	P_structured[(int)('M' - 'A')][(int)('E' - 'A')] = -0.058223294;	P_structured[(int)('M' - 'A')][(int)('N' - 'A')] = 0.048276836;	P_structured[(int)('M' - 'A')][(int)('T' - 'A')] = -0.222777179;	P_structured[(int)('M' - 'A')][(int)('D' - 'A')] = -0.947804514;	P_structured[(int)('M' - 'A')][(int)('V' - 'A')] = -0.5488354352;	P_structured[(int)('M' - 'A')][(int)('A' - 'A')] = -0.2510309363;	P_structured[(int)('M' - 'A')][(int)('G' - 'A')] = 0.07202825;	P_structured[(int)('M' - 'A')][(int)('R' - 'A')] = -0.039391625;	P_structured[(int)('M' - 'A')][(int)('F' - 'A')] = 0.3532253212;	P_structured[(int)('M' - 'A')][(int)('P' - 'A')] = -0.209356076;	P_structured[(int)('M' - 'A')][(int)('Q' - 'A')] = -0.03867894;	P_structured[(int)('M' - 'A')][(int)('Y' - 'A')] = 0.009194569;	P_structured[(int)('M' - 'A')][(int)('H' - 'A')] = 0.28887279;	P_structured[(int)('M' - 'A')][(int)('M' - 'A')] = -0.03982976;	P_structured[(int)('M' - 'A')][(int)('C' - 'A')] = -0.01268206;	P_structured[(int)('M' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('C' - 'A')][(int)('L' - 'A')] = 0.0002437666;	P_structured[(int)('C' - 'A')][(int)('S' - 'A')] = -0.054574325;	P_structured[(int)('C' - 'A')][(int)('K' - 'A')] = -0.00543178;	P_structured[(int)('C' - 'A')][(int)('I' - 'A')] = -0.040784258;	P_structured[(int)('C' - 'A')][(int)('E' - 'A')] = 0.014177066;	P_structured[(int)('C' - 'A')][(int)('N' - 'A')] = 0.014609641;	P_structured[(int)('C' - 'A')][(int)('T' - 'A')] = 0.057942768;	P_structured[(int)('C' - 'A')][(int)('D' - 'A')] = -0.00579898;	P_structured[(int)('C' - 'A')][(int)('V' - 'A')] = 0.0006924533;	P_structured[(int)('C' - 'A')][(int)('A' - 'A')] = -0.034757802;	P_structured[(int)('C' - 'A')][(int)('G' - 'A')] = 0.04763698;	P_structured[(int)('C' - 'A')][(int)('R' - 'A')] = -0.027158594;	P_structured[(int)('C' - 'A')][(int)('F' - 'A')] = 0.0641773129;	P_structured[(int)('C' - 'A')][(int)('P' - 'A')] = -0.008646095;	P_structured[(int)('C' - 'A')][(int)('Q' - 'A')] = -0.10187486;	P_structured[(int)('C' - 'A')][(int)('Y' - 'A')] = 0.967416658;	P_structured[(int)('C' - 'A')][(int)('H' - 'A')] = -0.41673112;	P_structured[(int)('C' - 'A')][(int)('M' - 'A')] = -0.35993122;	P_structured[(int)('C' - 'A')][(int)('C' - 'A')] = -0.007314886;	P_structured[(int)('C' - 'A')][(int)('W' - 'A')] = 0.2236068;
	P_structured[(int)('W' - 'A')][(int)('L' - 'A')] = -0.0004546277;	P_structured[(int)('W' - 'A')][(int)('S' - 'A')] = -0.002062643;	P_structured[(int)('W' - 'A')][(int)('K' - 'A')] = -0.00002015464;	P_structured[(int)('W' - 'A')][(int)('I' - 'A')] = -0.001555388;	P_structured[(int)('W' - 'A')][(int)('E' - 'A')] = 0.004241942;	P_structured[(int)('W' - 'A')][(int)('N' - 'A')] = -0.001717678;	P_structured[(int)('W' - 'A')][(int)('T' - 'A')] = 0.006346895;	P_structured[(int)('W' - 'A')][(int)('D' - 'A')] = -0.008113991;	P_structured[(int)('W' - 'A')][(int)('V' - 'A')] = 0.0144211451;	P_structured[(int)('W' - 'A')][(int)('A' - 'A')] = 0.0006457502;	P_structured[(int)('W' - 'A')][(int)('G' - 'A')] = 0.00002626486;	P_structured[(int)('W' - 'A')][(int)('R' - 'A')] = -0.002532496;	P_structured[(int)('W' - 'A')][(int)('F' - 'A')] = -0.0007943198;	P_structured[(int)('W' - 'A')][(int)('P' - 'A')] = 0.000116837;	P_structured[(int)('W' - 'A')][(int)('Q' - 'A')] = 0.0158619;	P_structured[(int)('W' - 'A')][(int)('Y' - 'A')] = -0.006579295;	P_structured[(int)('W' - 'A')][(int)('H' - 'A')] = -0.0157323;	P_structured[(int)('W' - 'A')][(int)('M' - 'A')] = 0.02561237;	P_structured[(int)('W' - 'A')][(int)('C' - 'A')] = 0.99820389;	P_structured[(int)('W' - 'A')][(int)('W' - 'A')] = 0.2236068;

	P1_structured[(int)('L' - 'A')][(int)('L' - 'A')] = 0.004820973;	P1_structured[(int)('L' - 'A')][(int)('S' - 'A')] = -0.0001682753;	P1_structured[(int)('L' - 'A')][(int)('K' - 'A')] = -0.001899002;	P1_structured[(int)('L' - 'A')][(int)('I' - 'A')] = -0.65675051;	P1_structured[(int)('L' - 'A')][(int)('E' - 'A')] = -0.009288224;	P1_structured[(int)('L' - 'A')][(int)('N' - 'A')] = 0.002116054;	P1_structured[(int)('L' - 'A')][(int)('T' - 'A')] = 0.146327787;	P1_structured[(int)('L' - 'A')][(int)('D' - 'A')] = -0.000765346;	P1_structured[(int)('L' - 'A')][(int)('V' - 'A')] = 0.71486105;	P1_structured[(int)('L' - 'A')][(int)('A' - 'A')] = -0.21945395;	P1_structured[(int)('L' - 'A')][(int)('G' - 'A')] = 0.002655219;	P1_structured[(int)('L' - 'A')][(int)('R' - 'A')] = 0.0006763002;	P1_structured[(int)('L' - 'A')][(int)('F' - 'A')] = 0.0020169773;	P1_structured[(int)('L' - 'A')][(int)('P' - 'A')] = 0.002235563;	P1_structured[(int)('L' - 'A')][(int)('Q' - 'A')] = 0.00001921296;	P1_structured[(int)('L' - 'A')][(int)('Y' - 'A')] = 0.0001004333;	P1_structured[(int)('L' - 'A')][(int)('H' - 'A')] = 0.000006407487;	P1_structured[(int)('L' - 'A')][(int)('M' - 'A')] = 0.012522039;	P1_structured[(int)('L' - 'A')][(int)('C' - 'A')] = 0.00005929078;	P1_structured[(int)('L' - 'A')][(int)('W' - 'A')] = -0.00009199501;
	P1_structured[(int)('S' - 'A')][(int)('L' - 'A')] = -0.100020237;	P1_structured[(int)('S' - 'A')][(int)('S' - 'A')] = 0.8058878438;	P1_structured[(int)('S' - 'A')][(int)('K' - 'A')] = 0.117068344;	P1_structured[(int)('S' - 'A')][(int)('I' - 'A')] = 0.0271389;	P1_structured[(int)('S' - 'A')][(int)('E' - 'A')] = -0.063910208;	P1_structured[(int)('S' - 'A')][(int)('N' - 'A')] = -0.473065135;	P1_structured[(int)('S' - 'A')][(int)('T' - 'A')] = -0.278502468;	P1_structured[(int)('S' - 'A')][(int)('D' - 'A')] = 0.166528399;	P1_structured[(int)('S' - 'A')][(int)('V' - 'A')] = 0.0642406;	P1_structured[(int)('S' - 'A')][(int)('A' - 'A')] = -0.06975288;	P1_structured[(int)('S' - 'A')][(int)('G' - 'A')] = -0.05562063;	P1_structured[(int)('S' - 'A')][(int)('R' - 'A')] = -0.0394195261;	P1_structured[(int)('S' - 'A')][(int)('F' - 'A')] = -0.0168175041;	P1_structured[(int)('S' - 'A')][(int)('P' - 'A')] = -0.090048301;	P1_structured[(int)('S' - 'A')][(int)('Q' - 'A')] = 0.002116836;	P1_structured[(int)('S' - 'A')][(int)('Y' - 'A')] = -0.0023312127;	P1_structured[(int)('S' - 'A')][(int)('H' - 'A')] = 0.01369684;	P1_structured[(int)('S' - 'A')][(int)('M' - 'A')] = 0.007023661;	P1_structured[(int)('S' - 'A')][(int)('C' - 'A')] = -0.01378003;	P1_structured[(int)('S' - 'A')][(int)('W' - 'A')] = -0.0004332998;
	P1_structured[(int)('K' - 'A')][(int)('L' - 'A')] = -0.014458345;	P1_structured[(int)('K' - 'A')][(int)('S' - 'A')] = 0.0491716641;	P1_structured[(int)('K' - 'A')][(int)('K' - 'A')] = -0.061665283;	P1_structured[(int)('K' - 'A')][(int)('I' - 'A')] = -0.16381123;	P1_structured[(int)('K' - 'A')][(int)('E' - 'A')] = 0.082975506;	P1_structured[(int)('K' - 'A')][(int)('N' - 'A')] = 0.344543771;	P1_structured[(int)('K' - 'A')][(int)('T' - 'A')] = -0.712657417;	P1_structured[(int)('K' - 'A')][(int)('D' - 'A')] = -0.207008208;	P1_structured[(int)('K' - 'A')][(int)('V' - 'A')] = 0.21696153;	P1_structured[(int)('K' - 'A')][(int)('A' - 'A')] = 0.49463389;	P1_structured[(int)('K' - 'A')][(int)('G' - 'A')] = -0.050928418;	P1_structured[(int)('K' - 'A')][(int)('R' - 'A')] = 0.0296327912;	P1_structured[(int)('K' - 'A')][(int)('F' - 'A')] = 0.0001967897;	P1_structured[(int)('K' - 'A')][(int)('P' - 'A')] = -0.009664584;	P1_structured[(int)('K' - 'A')][(int)('Q' - 'A')] = -0.005772179;	P1_structured[(int)('K' - 'A')][(int)('Y' - 'A')] = -0.0023589112;	P1_structured[(int)('K' - 'A')][(int)('H' - 'A')] = -0.01359006;	P1_structured[(int)('K' - 'A')][(int)('M' - 'A')] = 0.025392194;	P1_structured[(int)('K' - 'A')][(int)('C' - 'A')] = -0.001588594;	P1_structured[(int)('K' - 'A')][(int)('W' - 'A')] = -0.000004904054;
	P1_structured[(int)('I' - 'A')][(int)('L' - 'A')] = -0.083947895;	P1_structured[(int)('I' - 'A')][(int)('S' - 'A')] = 0.425492848;	P1_structured[(int)('I' - 'A')][(int)('K' - 'A')] = -0.325414012;	P1_structured[(int)('I' - 'A')][(int)('I' - 'A')] = 0.14267771;	P1_structured[(int)('I' - 'A')][(int)('E' - 'A')] = 0.445716763;	P1_structured[(int)('I' - 'A')][(int)('N' - 'A')] = 0.287177858;	P1_structured[(int)('I' - 'A')][(int)('T' - 'A')] = 0.06680358;	P1_structured[(int)('I' - 'A')][(int)('D' - 'A')] = -0.489001494;	P1_structured[(int)('I' - 'A')][(int)('V' - 'A')] = -0.0425641;	P1_structured[(int)('I' - 'A')][(int)('A' - 'A')] = -0.39658965;	P1_structured[(int)('I' - 'A')][(int)('G' - 'A')] = -0.032783164;	P1_structured[(int)('I' - 'A')][(int)('R' - 'A')] = 0.1255242114;	P1_structured[(int)('I' - 'A')][(int)('F' - 'A')] = -0.0087581433;	P1_structured[(int)('I' - 'A')][(int)('P' - 'A')] = -0.050879295;	P1_structured[(int)('I' - 'A')][(int)('Q' - 'A')] = -0.02788137;	P1_structured[(int)('I' - 'A')][(int)('Y' - 'A')] = -0.0040434746;	P1_structured[(int)('I' - 'A')][(int)('H' - 'A')] = -0.01686698;	P1_structured[(int)('I' - 'A')][(int)('M' - 'A')] = -0.003302597;	P1_structured[(int)('I' - 'A')][(int)('C' - 'A')] = -0.01101142;	P1_structured[(int)('I' - 'A')][(int)('W' - 'A')] = -0.0003493752;
	P1_structured[(int)('E' - 'A')][(int)('L' - 'A')] = -0.009822773;	P1_structured[(int)('E' - 'A')][(int)('S' - 'A')] = 0.0188388801;	P1_structured[(int)('E' - 'A')][(int)('K' - 'A')] = 0.727899054;	P1_structured[(int)('E' - 'A')][(int)('I' - 'A')] = 0.09575615;	P1_structured[(int)('E' - 'A')][(int)('E' - 'A')] = 0.007345574;	P1_structured[(int)('E' - 'A')][(int)('N' - 'A')] = 0.179706866;	P1_structured[(int)('E' - 'A')][(int)('T' - 'A')] = -0.062145636;	P1_structured[(int)('E' - 'A')][(int)('D' - 'A')] = -0.307585922;	P1_structured[(int)('E' - 'A')][(int)('V' - 'A')] = 0.02148911;	P1_structured[(int)('E' - 'A')][(int)('A' - 'A')] = -0.19450537;	P1_structured[(int)('E' - 'A')][(int)('G' - 'A')] = 0.087344391;	P1_structured[(int)('E' - 'A')][(int)('R' - 'A')] = -0.5772641544;	P1_structured[(int)('E' - 'A')][(int)('F' - 'A')] = -0.0010103197;	P1_structured[(int)('E' - 'A')][(int)('P' - 'A')] = 0.028297556;	P1_structured[(int)('E' - 'A')][(int)('Q' - 'A')] = -0.02970843;	P1_structured[(int)('E' - 'A')][(int)('Y' - 'A')] = -0.0016472508;	P1_structured[(int)('E' - 'A')][(int)('H' - 'A')] = 0.03405869;	P1_structured[(int)('E' - 'A')][(int)('M' - 'A')] = -0.022446019;	P1_structured[(int)('E' - 'A')][(int)('C' - 'A')] = 0.004323373;	P1_structured[(int)('E' - 'A')][(int)('W' - 'A')] = 0.001076226;
	P1_structured[(int)('N' - 'A')][(int)('L' - 'A')] = 0.192845571;	P1_structured[(int)('N' - 'A')][(int)('S' - 'A')] = -0.0626386838;	P1_structured[(int)('N' - 'A')][(int)('K' - 'A')] = 0.083292307;	P1_structured[(int)('N' - 'A')][(int)('I' - 'A')] = -0.31533277;	P1_structured[(int)('N' - 'A')][(int)('E' - 'A')] = 0.546316413;	P1_structured[(int)('N' - 'A')][(int)('N' - 'A')] = -0.452355874;	P1_structured[(int)('N' - 'A')][(int)('T' - 'A')] = 0.229066743;	P1_structured[(int)('N' - 'A')][(int)('D' - 'A')] = -0.320113489;	P1_structured[(int)('N' - 'A')][(int)('V' - 'A')] = -0.13522815;	P1_structured[(int)('N' - 'A')][(int)('A' - 'A')] = 0.43031403;	P1_structured[(int)('N' - 'A')][(int)('G' - 'A')] = -0.03496376;	P1_structured[(int)('N' - 'A')][(int)('R' - 'A')] = -0.0754768538;	P1_structured[(int)('N' - 'A')][(int)('F' - 'A')] = -0.0180581018;	P1_structured[(int)('N' - 'A')][(int)('P' - 'A')] = -0.051727327;	P1_structured[(int)('N' - 'A')][(int)('Q' - 'A')] = -0.1071026;	P1_structured[(int)('N' - 'A')][(int)('Y' - 'A')] = 0.00702388;	P1_structured[(int)('N' - 'A')][(int)('H' - 'A')] = 0.06305007;	P1_structured[(int)('N' - 'A')][(int)('M' - 'A')] = 0.017343061;	P1_structured[(int)('N' - 'A')][(int)('C' - 'A')] = 0.00415164;	P1_structured[(int)('N' - 'A')][(int)('W' - 'A')] = -0.0004060914;
	P1_structured[(int)('T' - 'A')][(int)('L' - 'A')] = -0.365234699;	P1_structured[(int)('T' - 'A')][(int)('S' - 'A')] = -0.4012335643;	P1_structured[(int)('T' - 'A')][(int)('K' - 'A')] = -0.004463804;	P1_structured[(int)('T' - 'A')][(int)('I' - 'A')] = 0.44149119;	P1_structured[(int)('T' - 'A')][(int)('E' - 'A')] = 0.315282214;	P1_structured[(int)('T' - 'A')][(int)('N' - 'A')] = -0.361378081;	P1_structured[(int)('T' - 'A')][(int)('T' - 'A')] = -0.2923931;	P1_structured[(int)('T' - 'A')][(int)('D' - 'A')] = -0.016341897;	P1_structured[(int)('T' - 'A')][(int)('V' - 'A')] = 0.34626647;	P1_structured[(int)('T' - 'A')][(int)('A' - 'A')] = -0.19339036;	P1_structured[(int)('T' - 'A')][(int)('G' - 'A')] = 0.192134878;	P1_structured[(int)('T' - 'A')][(int)('R' - 'A')] = 0.0961708835;	P1_structured[(int)('T' - 'A')][(int)('F' - 'A')] = 0.0815627631;	P1_structured[(int)('T' - 'A')][(int)('P' - 'A')] = 0.266392129;	P1_structured[(int)('T' - 'A')][(int)('Q' - 'A')] = -0.09895254;	P1_structured[(int)('T' - 'A')][(int)('Y' - 'A')] = -0.0014411176;	P1_structured[(int)('T' - 'A')][(int)('H' - 'A')] = 0.05820323;	P1_structured[(int)('T' - 'A')][(int)('M' - 'A')] = -0.080817329;	P1_structured[(int)('T' - 'A')][(int)('C' - 'A')] = 0.01662746;	P1_structured[(int)('T' - 'A')][(int)('W' - 'A')] = 0.001515271;
	P1_structured[(int)('D' - 'A')][(int)('L' - 'A')] = 1.000587728;	P1_structured[(int)('D' - 'A')][(int)('S' - 'A')] = 0.0190717128;	P1_structured[(int)('D' - 'A')][(int)('K' - 'A')] = 0.011182225;	P1_structured[(int)('D' - 'A')][(int)('I' - 'A')] = 0.08656517;	P1_structured[(int)('D' - 'A')][(int)('E' - 'A')] = 0.00547463;	P1_structured[(int)('D' - 'A')][(int)('N' - 'A')] = 0.01048206;	P1_structured[(int)('D' - 'A')][(int)('T' - 'A')] = -0.083018526;	P1_structured[(int)('D' - 'A')][(int)('D' - 'A')] = 0.031827981;	P1_structured[(int)('D' - 'A')][(int)('V' - 'A')] = 0.10898113;	P1_structured[(int)('D' - 'A')][(int)('A' - 'A')] = -0.03778661;	P1_structured[(int)('D' - 'A')][(int)('G' - 'A')] = -0.028148354;	P1_structured[(int)('D' - 'A')][(int)('R' - 'A')] = 0.0713111929;	P1_structured[(int)('D' - 'A')][(int)('F' - 'A')] = -0.2999280702;	P1_structured[(int)('D' - 'A')][(int)('P' - 'A')] = -0.116829418;	P1_structured[(int)('D' - 'A')][(int)('Q' - 'A')] = -0.07335808;	P1_structured[(int)('D' - 'A')][(int)('Y' - 'A')] = 0.0369572419;	P1_structured[(int)('D' - 'A')][(int)('H' - 'A')] = -0.01991247;	P1_structured[(int)('D' - 'A')][(int)('M' - 'A')] = -0.715960774;	P1_structured[(int)('D' - 'A')][(int)('C' - 'A')] = -0.003465094;	P1_structured[(int)('D' - 'A')][(int)('W' - 'A')] = -0.004033678;
	P1_structured[(int)('V' - 'A')][(int)('L' - 'A')] = -0.757226421;	P1_structured[(int)('V' - 'A')][(int)('S' - 'A')] = 0.0825590244;	P1_structured[(int)('V' - 'A')][(int)('K' - 'A')] = 0.011375183;	P1_structured[(int)('V' - 'A')][(int)('I' - 'A')] = 0.2694926;	P1_structured[(int)('V' - 'A')][(int)('E' - 'A')] = 0.03248565;	P1_structured[(int)('V' - 'A')][(int)('N' - 'A')] = 0.095329112;	P1_structured[(int)('V' - 'A')][(int)('T' - 'A')] = 0.300096214;	P1_structured[(int)('V' - 'A')][(int)('D' - 'A')] = 0.031371249;	P1_structured[(int)('V' - 'A')][(int)('V' - 'A')] = 0.26071197;	P1_structured[(int)('V' - 'A')][(int)('A' - 'A')] = 0.30824333;	P1_structured[(int)('V' - 'A')][(int)('G' - 'A')] = -0.493218272;	P1_structured[(int)('V' - 'A')][(int)('R' - 'A')] = -0.1046427696;	P1_structured[(int)('V' - 'A')][(int)('F' - 'A')] = 0.2205709645;	P1_structured[(int)('V' - 'A')][(int)('P' - 'A')] = -0.105729248;	P1_structured[(int)('V' - 'A')][(int)('Q' - 'A')] = 0.1071702;	P1_structured[(int)('V' - 'A')][(int)('Y' - 'A')] = -0.0351289382;	P1_structured[(int)('V' - 'A')][(int)('H' - 'A')] = -0.005743218;	P1_structured[(int)('V' - 'A')][(int)('M' - 'A')] = -0.22177298;	P1_structured[(int)('V' - 'A')][(int)('C' - 'A')] = 0.0002213377;	P1_structured[(int)('V' - 'A')][(int)('W' - 'A')] = 0.003834977;
	P1_structured[(int)('A' - 'A')][(int)('L' - 'A')] = -0.271224256;	P1_structured[(int)('A' - 'A')][(int)('S' - 'A')] = 0.0744935586;	P1_structured[(int)('A' - 'A')][(int)('K' - 'A')] = -0.11693254;	P1_structured[(int)('A' - 'A')][(int)('I' - 'A')] = 0.04933264;	P1_structured[(int)('A' - 'A')][(int)('E' - 'A')] = -0.34892089;	P1_structured[(int)('A' - 'A')][(int)('N' - 'A')] = -0.138159464;	P1_structured[(int)('A' - 'A')][(int)('T' - 'A')] = 0.123932343;	P1_structured[(int)('A' - 'A')][(int)('D' - 'A')] = -0.424089381;	P1_structured[(int)('A' - 'A')][(int)('V' - 'A')] = 0.07884893;	P1_structured[(int)('A' - 'A')][(int)('A' - 'A')] = 0.20175039;	P1_structured[(int)('A' - 'A')][(int)('G' - 'A')] = 0.672429368;	P1_structured[(int)('A' - 'A')][(int)('R' - 'A')] = 0.0450053787;	P1_structured[(int)('A' - 'A')][(int)('F' - 'A')] = 0.0825639115;	P1_structured[(int)('A' - 'A')][(int)('P' - 'A')] = -0.180597107;	P1_structured[(int)('A' - 'A')][(int)('Q' - 'A')] = 0.303833;	P1_structured[(int)('A' - 'A')][(int)('Y' - 'A')] = 0.0009108578;	P1_structured[(int)('A' - 'A')][(int)('H' - 'A')] = -0.03684729;	P1_structured[(int)('A' - 'A')][(int)('M' - 'A')] = -0.105006246;	P1_structured[(int)('A' - 'A')][(int)('C' - 'A')] = -0.01150096;	P1_structured[(int)('A' - 'A')][(int)('W' - 'A')] = 0.0001777664;
	P1_structured[(int)('G' - 'A')][(int)('L' - 'A')] = 0.232126651;	P1_structured[(int)('G' - 'A')][(int)('S' - 'A')] = -0.1317681916;	P1_structured[(int)('G' - 'A')][(int)('K' - 'A')] = -0.264800869;	P1_structured[(int)('G' - 'A')][(int)('I' - 'A')] = 0.02130639;	P1_structured[(int)('G' - 'A')][(int)('E' - 'A')] = 0.348855225;	P1_structured[(int)('G' - 'A')][(int)('N' - 'A')] = -0.141479527;	P1_structured[(int)('G' - 'A')][(int)('T' - 'A')] = -0.119503987;	P1_structured[(int)('G' - 'A')][(int)('D' - 'A')] = 0.141514066;	P1_structured[(int)('G' - 'A')][(int)('V' - 'A')] = 0.01724199;	P1_structured[(int)('G' - 'A')][(int)('A' - 'A')] = -0.08447462;	P1_structured[(int)('G' - 'A')][(int)('G' - 'A')] = -0.131095773;	P1_structured[(int)('G' - 'A')][(int)('R' - 'A')] = -0.3610406499;	P1_structured[(int)('G' - 'A')][(int)('F' - 'A')] = -0.1716644393;	P1_structured[(int)('G' - 'A')][(int)('P' - 'A')] = 0.110352133;	P1_structured[(int)('G' - 'A')][(int)('Q' - 'A')] = 0.6956048;	P1_structured[(int)('G' - 'A')][(int)('Y' - 'A')] = 0.1191279148;	P1_structured[(int)('G' - 'A')][(int)('H' - 'A')] = -0.3446409;	P1_structured[(int)('G' - 'A')][(int)('M' - 'A')] = 0.042234339;	P1_structured[(int)('G' - 'A')][(int)('C' - 'A')] = 0.02209534;	P1_structured[(int)('G' - 'A')][(int)('W' - 'A')] = 0.0000101351;
	P1_structured[(int)('R' - 'A')][(int)('L' - 'A')] = -0.149704884;	P1_structured[(int)('R' - 'A')][(int)('S' - 'A')] = 0.0924903062;	P1_structured[(int)('R' - 'A')][(int)('K' - 'A')] = 0.558985592;	P1_structured[(int)('R' - 'A')][(int)('I' - 'A')] = -0.08650558;	P1_structured[(int)('R' - 'A')][(int)('E' - 'A')] = -0.165483229;	P1_structured[(int)('R' - 'A')][(int)('N' - 'A')] = -0.075446168;	P1_structured[(int)('R' - 'A')][(int)('T' - 'A')] = 0.084299211;	P1_structured[(int)('R' - 'A')][(int)('D' - 'A')] = -0.293685564;	P1_structured[(int)('R' - 'A')][(int)('V' - 'A')] = -0.06697762;	P1_structured[(int)('R' - 'A')][(int)('A' - 'A')] = 0.05568704;	P1_structured[(int)('R' - 'A')][(int)('G' - 'A')] = -0.13434278;	P1_structured[(int)('R' - 'A')][(int)('R' - 'A')] = 0.4505182974;	P1_structured[(int)('R' - 'A')][(int)('F' - 'A')] = -0.0185319263;	P1_structured[(int)('R' - 'A')][(int)('P' - 'A')] = 0.351964721;	P1_structured[(int)('R' - 'A')][(int)('Q' - 'A')] = -0.1497777;	P1_structured[(int)('R' - 'A')][(int)('Y' - 'A')] = 0.1751855506;	P1_structured[(int)('R' - 'A')][(int)('H' - 'A')] = -0.5867228;	P1_structured[(int)('R' - 'A')][(int)('M' - 'A')] = -0.026423626;	P1_structured[(int)('R' - 'A')][(int)('C' - 'A')] = -0.01441085;	P1_structured[(int)('R' - 'A')][(int)('W' - 'A')] = -0.00111798;
	P1_structured[(int)('F' - 'A')][(int)('L' - 'A')] = 0.078971401;	P1_structured[(int)('F' - 'A')][(int)('S' - 'A')] = -0.2574464872;	P1_structured[(int)('F' - 'A')][(int)('K' - 'A')] = 0.224368734;	P1_structured[(int)('F' - 'A')][(int)('I' - 'A')] = 0.40860913;	P1_structured[(int)('F' - 'A')][(int)('E' - 'A')] = 0.111232025;	P1_structured[(int)('F' - 'A')][(int)('N' - 'A')] = -0.037732227;	P1_structured[(int)('F' - 'A')][(int)('T' - 'A')] = -0.009329637;	P1_structured[(int)('F' - 'A')][(int)('D' - 'A')] = 0.04031851;	P1_structured[(int)('F' - 'A')][(int)('V' - 'A')] = 0.29959912;	P1_structured[(int)('F' - 'A')][(int)('A' - 'A')] = -0.03129004;	P1_structured[(int)('F' - 'A')][(int)('G' - 'A')] = -0.027402279;	P1_structured[(int)('F' - 'A')][(int)('R' - 'A')] = 0.1322226328;	P1_structured[(int)('F' - 'A')][(int)('F' - 'A')] = -0.3020362382;	P1_structured[(int)('F' - 'A')][(int)('P' - 'A')] = -0.732322743;	P1_structured[(int)('F' - 'A')][(int)('Q' - 'A')] = -0.1012257;	P1_structured[(int)('F' - 'A')][(int)('Y' - 'A')] = 0.1494459986;	P1_structured[(int)('F' - 'A')][(int)('H' - 'A')] = -0.1528608;	P1_structured[(int)('F' - 'A')][(int)('M' - 'A')] = 0.181116295;	P1_structured[(int)('F' - 'A')][(int)('C' - 'A')] = 0.02603039;	P1_structured[(int)('F' - 'A')][(int)('W' - 'A')] = -0.0002680386;
	P1_structured[(int)('P' - 'A')][(int)('L' - 'A')] = -0.02733773;	P1_structured[(int)('P' - 'A')][(int)('S' - 'A')] = -0.0331478434;	P1_structured[(int)('P' - 'A')][(int)('K' - 'A')] = -0.004555548;	P1_structured[(int)('P' - 'A')][(int)('I' - 'A')] = -0.23809162;	P1_structured[(int)('P' - 'A')][(int)('E' - 'A')] = 0.308320816;	P1_structured[(int)('P' - 'A')][(int)('N' - 'A')] = 0.085376287;	P1_structured[(int)('P' - 'A')][(int)('T' - 'A')] = -0.112296663;	P1_structured[(int)('P' - 'A')][(int)('D' - 'A')] = 0.341145814;	P1_structured[(int)('P' - 'A')][(int)('V' - 'A')] = -0.18140238;	P1_structured[(int)('P' - 'A')][(int)('A' - 'A')] = -0.09619279;	P1_structured[(int)('P' - 'A')][(int)('G' - 'A')] = 0.279337637;	P1_structured[(int)('P' - 'A')][(int)('R' - 'A')] = -0.0996386991;	P1_structured[(int)('P' - 'A')][(int)('F' - 'A')] = 0.7173785864;	P1_structured[(int)('P' - 'A')][(int)('P' - 'A')] = -0.265721863;	P1_structured[(int)('P' - 'A')][(int)('Q' - 'A')] = -0.1575578;	P1_structured[(int)('P' - 'A')][(int)('Y' - 'A')] = -0.1575176757;	P1_structured[(int)('P' - 'A')][(int)('H' - 'A')] = -0.2547787;	P1_structured[(int)('P' - 'A')][(int)('M' - 'A')] = -0.100086915;	P1_structured[(int)('P' - 'A')][(int)('C' - 'A')] = -0.003269671;	P1_structured[(int)('P' - 'A')][(int)('W' - 'A')] = 0.00003675971;
	P1_structured[(int)('Q' - 'A')][(int)('L' - 'A')] = -0.316752769;	P1_structured[(int)('Q' - 'A')][(int)('S' - 'A')] = 0.2127690967;	P1_structured[(int)('Q' - 'A')][(int)('K' - 'A')] = -0.351119236;	P1_structured[(int)('Q' - 'A')][(int)('I' - 'A')] = 0.06547061;	P1_structured[(int)('Q' - 'A')][(int)('E' - 'A')] = 0.097785635;	P1_structured[(int)('Q' - 'A')][(int)('N' - 'A')] = 0.149123808;	P1_structured[(int)('Q' - 'A')][(int)('T' - 'A')] = 0.173604534;	P1_structured[(int)('Q' - 'A')][(int)('D' - 'A')] = 0.274931146;	P1_structured[(int)('Q' - 'A')][(int)('V' - 'A')] = 0.08972533;	P1_structured[(int)('Q' - 'A')][(int)('A' - 'A')] = 0.22320368;	P1_structured[(int)('Q' - 'A')][(int)('G' - 'A')] = 0.347258281;	P1_structured[(int)('Q' - 'A')][(int)('R' - 'A')] = -0.3491544144;	P1_structured[(int)('Q' - 'A')][(int)('F' - 'A')] = -0.4100611262;	P1_structured[(int)('Q' - 'A')][(int)('P' - 'A')] = 0.141088759;	P1_structured[(int)('Q' - 'A')][(int)('Q' - 'A')] = -0.3731951;	P1_structured[(int)('Q' - 'A')][(int)('Y' - 'A')] = 0.2298427391;	P1_structured[(int)('Q' - 'A')][(int)('H' - 'A')] = -0.1552879;	P1_structured[(int)('Q' - 'A')][(int)('M' - 'A')] = -0.017498335;	P1_structured[(int)('Q' - 'A')][(int)('C' - 'A')] = -0.03645718;	P1_structured[(int)('Q' - 'A')][(int)('W' - 'A')] = 0.004722518;
	P1_structured[(int)('Y' - 'A')][(int)('L' - 'A')] = 0.014202237;	P1_structured[(int)('Y' - 'A')][(int)('S' - 'A')] = 0.1040831511;	P1_structured[(int)('Y' - 'A')][(int)('K' - 'A')] = -0.12880272;	P1_structured[(int)('Y' - 'A')][(int)('I' - 'A')] = 0.04556199;	P1_structured[(int)('Y' - 'A')][(int)('E' - 'A')] = -0.105340037;	P1_structured[(int)('Y' - 'A')][(int)('N' - 'A')] = -0.025376394;	P1_structured[(int)('Y' - 'A')][(int)('T' - 'A')] = 0.043186347;	P1_structured[(int)('Y' - 'A')][(int)('D' - 'A')] = -0.068409434;	P1_structured[(int)('Y' - 'A')][(int)('V' - 'A')] = 0.03936435;	P1_structured[(int)('Y' - 'A')][(int)('A' - 'A')] = 0.04822618;	P1_structured[(int)('Y' - 'A')][(int)('G' - 'A')] = 0.014870689;	P1_structured[(int)('Y' - 'A')][(int)('R' - 'A')] = -0.0733196407;	P1_structured[(int)('Y' - 'A')][(int)('F' - 'A')] = -0.1476041712;	P1_structured[(int)('Y' - 'A')][(int)('P' - 'A')] = 0.044812431;	P1_structured[(int)('Y' - 'A')][(int)('Q' - 'A')] = -0.1144861;	P1_structured[(int)('Y' - 'A')][(int)('Y' - 'A')] = -0.4721449992;	P1_structured[(int)('Y' - 'A')][(int)('H' - 'A')] = -0.1120941;	P1_structured[(int)('Y' - 'A')][(int)('M' - 'A')] = 0.010664852;	P1_structured[(int)('Y' - 'A')][(int)('C' - 'A')] = 0.8876276;	P1_structured[(int)('Y' - 'A')][(int)('W' - 'A')] = -0.00502226;
	P1_structured[(int)('H' - 'A')][(int)('L' - 'A')] = 0.642559812;	P1_structured[(int)('H' - 'A')][(int)('S' - 'A')] = 0.0429304502;	P1_structured[(int)('H' - 'A')][(int)('K' - 'A')] = -0.294224109;	P1_structured[(int)('H' - 'A')][(int)('I' - 'A')] = 0.43150217;	P1_structured[(int)('H' - 'A')][(int)('E' - 'A')] = -0.24852629;	P1_structured[(int)('H' - 'A')][(int)('N' - 'A')] = -0.125054089;	P1_structured[(int)('H' - 'A')][(int)('T' - 'A')] = 0.113268953;	P1_structured[(int)('H' - 'A')][(int)('D' - 'A')] = -0.212495123;	P1_structured[(int)('H' - 'A')][(int)('V' - 'A')] = 0.33276637;	P1_structured[(int)('H' - 'A')][(int)('A' - 'A')] = 0.12549854;	P1_structured[(int)('H' - 'A')][(int)('G' - 'A')] = -0.118069145;	P1_structured[(int)('H' - 'A')][(int)('R' - 'A')] = -0.2061163651;	P1_structured[(int)('H' - 'A')][(int)('F' - 'A')] = 0.2055227932;	P1_structured[(int)('H' - 'A')][(int)('P' - 'A')] = 0.09475695;	P1_structured[(int)('H' - 'A')][(int)('Q' - 'A')] = -0.1718643;	P1_structured[(int)('H' - 'A')][(int)('Y' - 'A')] = -0.4346438379;	P1_structured[(int)('H' - 'A')][(int)('H' - 'A')] = -0.1534945;	P1_structured[(int)('H' - 'A')][(int)('M' - 'A')] = 0.137398044;	P1_structured[(int)('H' - 'A')][(int)('C' - 'A')] = -0.1567918;	P1_structured[(int)('H' - 'A')][(int)('W' - 'A')] = -0.004924497;
	P1_structured[(int)('M' - 'A')][(int)('L' - 'A')] = -0.270949396;	P1_structured[(int)('M' - 'A')][(int)('S' - 'A')] = 0.0606254344;	P1_structured[(int)('M' - 'A')][(int)('K' - 'A')] = 0.310613635;	P1_structured[(int)('M' - 'A')][(int)('I' - 'A')] = -0.05879622;	P1_structured[(int)('M' - 'A')][(int)('E' - 'A')] = 0.282672133;	P1_structured[(int)('M' - 'A')][(int)('N' - 'A')] = 0.142373604;	P1_structured[(int)('M' - 'A')][(int)('T' - 'A')] = 0.061335499;	P1_structured[(int)('M' - 'A')][(int)('D' - 'A')] = 0.230102202;	P1_structured[(int)('M' - 'A')][(int)('V' - 'A')] = -0.03016143;	P1_structured[(int)('M' - 'A')][(int)('A' - 'A')] = 0.06305118;	P1_structured[(int)('M' - 'A')][(int)('G' - 'A')] = 0.184609826;	P1_structured[(int)('M' - 'A')][(int)('R' - 'A')] = 0.1785976263;	P1_structured[(int)('M' - 'A')][(int)('F' - 'A')] = -0.4500948552;	P1_structured[(int)('M' - 'A')][(int)('P' - 'A')] = 0.023006859;	P1_structured[(int)('M' - 'A')][(int)('Q' - 'A')] = 0.137735;	P1_structured[(int)('M' - 'A')][(int)('Y' - 'A')] = -0.6891308679;	P1_structured[(int)('M' - 'A')][(int)('H' - 'A')] = -0.0245548;	P1_structured[(int)('M' - 'A')][(int)('M' - 'A')] = -0.019551137;	P1_structured[(int)('M' - 'A')][(int)('C' - 'A')] = -0.1397582;	P1_structured[(int)('M' - 'A')][(int)('W' - 'A')] = 0.008273898;
	P1_structured[(int)('C' - 'A')][(int)('L' - 'A')] = -0.066453109;	P1_structured[(int)('C' - 'A')][(int)('S' - 'A')] = -0.0733859939;	P1_structured[(int)('C' - 'A')][(int)('K' - 'A')] = -0.077889384;	P1_structured[(int)('C' - 'A')][(int)('I' - 'A')] = -0.07476116;	P1_structured[(int)('C' - 'A')][(int)('E' - 'A')] = -0.075217324;	P1_structured[(int)('C' - 'A')][(int)('N' - 'A')] = -0.063671219;	P1_structured[(int)('C' - 'A')][(int)('T' - 'A')] = -0.059206118;	P1_structured[(int)('C' - 'A')][(int)('D' - 'A')] = -0.071420363;	P1_structured[(int)('C' - 'A')][(int)('V' - 'A')] = -0.06278723;	P1_structured[(int)('C' - 'A')][(int)('A' - 'A')] = -0.06014833;	P1_structured[(int)('C' - 'A')][(int)('G' - 'A')] = -0.059469628;	P1_structured[(int)('C' - 'A')][(int)('R' - 'A')] = -0.0401193648;	P1_structured[(int)('C' - 'A')][(int)('F' - 'A')] = -0.0392948581;	P1_structured[(int)('C' - 'A')][(int)('P' - 'A')] = -0.040737698;	P1_structured[(int)('C' - 'A')][(int)('Q' - 'A')] = -0.03846629;	P1_structured[(int)('C' - 'A')][(int)('Y' - 'A')] = -0.0334608292;	P1_structured[(int)('C' - 'A')][(int)('H' - 'A')] = -0.02368212;	P1_structured[(int)('C' - 'A')][(int)('M' - 'A')] = -0.01907249;	P1_structured[(int)('C' - 'A')][(int)('C' - 'A')] = -0.008701996;	P1_structured[(int)('C' - 'A')][(int)('W' - 'A')] = 0.9879455;
	P1_structured[(int)('W' - 'A')][(int)('L' - 'A')] = 0.490820551;	P1_structured[(int)('W' - 'A')][(int)('S' - 'A')] = 0.3279143027;	P1_structured[(int)('W' - 'A')][(int)('K' - 'A')] = 0.305480652;	P1_structured[(int)('W' - 'A')][(int)('I' - 'A')] = 0.33686616;	P1_structured[(int)('W' - 'A')][(int)('E' - 'A')] = 0.270916194;	P1_structured[(int)('W' - 'A')][(int)('N' - 'A')] = 0.242461091;	P1_structured[(int)('W' - 'A')][(int)('T' - 'A')] = 0.24183834;	P1_structured[(int)('W' - 'A')][(int)('D' - 'A')] = 0.254938449;	P1_structured[(int)('W' - 'A')][(int)('V' - 'A')] = 0.27975502;	P1_structured[(int)('W' - 'A')][(int)('A' - 'A')] = 0.24312901;	P1_structured[(int)('W' - 'A')][(int)('G' - 'A')] = 0.230807346;	P1_structured[(int)('W' - 'A')][(int)('R' - 'A')] = 0.1897769302;	P1_structured[(int)('W' - 'A')][(int)('F' - 'A')] = 0.236545052;	P1_structured[(int)('W' - 'A')][(int)('P' - 'A')] = 0.172134347;	P1_structured[(int)('W' - 'A')][(int)('Q' - 'A')] = 0.156822;	P1_structured[(int)('W' - 'A')][(int)('Y' - 'A')] = 0.1737941677;	P1_structured[(int)('W' - 'A')][(int)('H' - 'A')] = 0.09638379;	P1_structured[(int)('W' - 'A')][(int)('M' - 'A')] = 0.090543109;	P1_structured[(int)('W' - 'A')][(int)('C' - 'A')] = 0.07162242;	P1_structured[(int)('W' - 'A')][(int)('W' - 'A')] = 0.059587;
	
	P_disordered[(int)('L' - 'A')][(int)('L' - 'A')] = -0.046514267;	P_disordered[(int)('L' - 'A')][(int)('S' - 'A')] = 0.0194890589;	P_disordered[(int)('L' - 'A')][(int)('K' - 'A')] = 0.035726926;	P_disordered[(int)('L' - 'A')][(int)('I' - 'A')] = 0.0015999777;	P_disordered[(int)('L' - 'A')][(int)('E' - 'A')] = 0.0124637935;	P_disordered[(int)('L' - 'A')][(int)('N' - 'A')] = 0.0352867954;	P_disordered[(int)('L' - 'A')][(int)('T' - 'A')] = -0.037826477;	P_disordered[(int)('L' - 'A')][(int)('D' - 'A')] = 0.007208588;	P_disordered[(int)('L' - 'A')][(int)('V' - 'A')] = 0.17744182;	P_disordered[(int)('L' - 'A')][(int)('A' - 'A')] = -0.2545326267;	P_disordered[(int)('L' - 'A')][(int)('G' - 'A')] = -0.364510321;	P_disordered[(int)('L' - 'A')][(int)('R' - 'A')] = 0.184384759;	P_disordered[(int)('L' - 'A')][(int)('F' - 'A')] = 0.3147388;	P_disordered[(int)('L' - 'A')][(int)('P' - 'A')] = 0.168703125;	P_disordered[(int)('L' - 'A')][(int)('Q' - 'A')] = -0.118352406;	P_disordered[(int)('L' - 'A')][(int)('Y' - 'A')] = 0.0058425555;	P_disordered[(int)('L' - 'A')][(int)('H' - 'A')] = -0.29923499;	P_disordered[(int)('L' - 'A')][(int)('M' - 'A')] = -0.022104426;	P_disordered[(int)('L' - 'A')][(int)('C' - 'A')] = -0.001904101;	P_disordered[(int)('L' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('S' - 'A')][(int)('L' - 'A')] = 0.536052827;	P_disordered[(int)('S' - 'A')][(int)('S' - 'A')] = -0.1775835905;	P_disordered[(int)('S' - 'A')][(int)('K' - 'A')] = -0.301182233;	P_disordered[(int)('S' - 'A')][(int)('I' - 'A')] = 0.0274727461;	P_disordered[(int)('S' - 'A')][(int)('E' - 'A')] = -0.0295883052;	P_disordered[(int)('S' - 'A')][(int)('N' - 'A')] = -0.1445391525;	P_disordered[(int)('S' - 'A')][(int)('T' - 'A')] = -0.1627421919;	P_disordered[(int)('S' - 'A')][(int)('D' - 'A')] = 0.035649446;	P_disordered[(int)('S' - 'A')][(int)('V' - 'A')] = 0.038272961;	P_disordered[(int)('S' - 'A')][(int)('A' - 'A')] = 0.0270952775;	P_disordered[(int)('S' - 'A')][(int)('G' - 'A')] = -0.011225893;	P_disordered[(int)('S' - 'A')][(int)('R' - 'A')] = -0.070399159;	P_disordered[(int)('S' - 'A')][(int)('F' - 'A')] = 0.04883091;	P_disordered[(int)('S' - 'A')][(int)('P' - 'A')] = -0.177971172;	P_disordered[(int)('S' - 'A')][(int)('Q' - 'A')] = -0.021440652;	P_disordered[(int)('S' - 'A')][(int)('Y' - 'A')] = -0.0047020782;	P_disordered[(int)('S' - 'A')][(int)('H' - 'A')] = -0.00764406;	P_disordered[(int)('S' - 'A')][(int)('M' - 'A')] = 0.020979492;	P_disordered[(int)('S' - 'A')][(int)('C' - 'A')] = -0.003291947;	P_disordered[(int)('S' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('K' - 'A')][(int)('L' - 'A')] = 0.151307946;	P_disordered[(int)('K' - 'A')][(int)('S' - 'A')] = 0.0669859495;	P_disordered[(int)('K' - 'A')][(int)('K' - 'A')] = 0.266225084;	P_disordered[(int)('K' - 'A')][(int)('I' - 'A')] = 0.5250002298;	P_disordered[(int)('K' - 'A')][(int)('E' - 'A')] = 0.1091717352;	P_disordered[(int)('K' - 'A')][(int)('N' - 'A')] = 0.002100269;	P_disordered[(int)('K' - 'A')][(int)('T' - 'A')] = 0.0178051605;	P_disordered[(int)('K' - 'A')][(int)('D' - 'A')] = -0.069637865;	P_disordered[(int)('K' - 'A')][(int)('V' - 'A')] = 0.223366185;	P_disordered[(int)('K' - 'A')][(int)('A' - 'A')] = 0.2359366448;	P_disordered[(int)('K' - 'A')][(int)('G' - 'A')] = -0.058524521;	P_disordered[(int)('K' - 'A')][(int)('R' - 'A')] = 0.042937514;	P_disordered[(int)('K' - 'A')][(int)('F' - 'A')] = -0.06397982;	P_disordered[(int)('K' - 'A')][(int)('P' - 'A')] = 0.161294856;	P_disordered[(int)('K' - 'A')][(int)('Q' - 'A')] = 0.0907038;	P_disordered[(int)('K' - 'A')][(int)('Y' - 'A')] = 0.0078205187;	P_disordered[(int)('K' - 'A')][(int)('H' - 'A')] = 0.13878364;	P_disordered[(int)('K' - 'A')][(int)('M' - 'A')] = 0.050325237;	P_disordered[(int)('K' - 'A')][(int)('C' - 'A')] = -0.00353643;	P_disordered[(int)('K' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('I' - 'A')][(int)('L' - 'A')] = 0.02931038;	P_disordered[(int)('I' - 'A')][(int)('S' - 'A')] = -0.125079104;	P_disordered[(int)('I' - 'A')][(int)('K' - 'A')] = 0.107426795;	P_disordered[(int)('I' - 'A')][(int)('I' - 'A')] = -0.1742862699;	P_disordered[(int)('I' - 'A')][(int)('E' - 'A')] = 0.4769866845;	P_disordered[(int)('I' - 'A')][(int)('N' - 'A')] = -0.4848762857;	P_disordered[(int)('I' - 'A')][(int)('T' - 'A')] = 0.2574254945;	P_disordered[(int)('I' - 'A')][(int)('D' - 'A')] = -0.076810992;	P_disordered[(int)('I' - 'A')][(int)('V' - 'A')] = -0.093851663;	P_disordered[(int)('I' - 'A')][(int)('A' - 'A')] = 0.1118897778;	P_disordered[(int)('I' - 'A')][(int)('G' - 'A')] = 0.318601588;	P_disordered[(int)('I' - 'A')][(int)('R' - 'A')] = 0.28750418;	P_disordered[(int)('I' - 'A')][(int)('F' - 'A')] = -0.14426011;	P_disordered[(int)('I' - 'A')][(int)('P' - 'A')] = 0.076319913;	P_disordered[(int)('I' - 'A')][(int)('Q' - 'A')] = -0.244841793;	P_disordered[(int)('I' - 'A')][(int)('Y' - 'A')] = 0.0066200499;	P_disordered[(int)('I' - 'A')][(int)('H' - 'A')] = -0.22870406;	P_disordered[(int)('I' - 'A')][(int)('M' - 'A')] = 0.015943627;	P_disordered[(int)('I' - 'A')][(int)('C' - 'A')] = -0.003385302;	P_disordered[(int)('I' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('E' - 'A')][(int)('L' - 'A')] = -0.094602623;	P_disordered[(int)('E' - 'A')][(int)('S' - 'A')] = -0.1224867567;	P_disordered[(int)('E' - 'A')][(int)('K' - 'A')] = -0.391424113;	P_disordered[(int)('E' - 'A')][(int)('I' - 'A')] = -0.0101217944;	P_disordered[(int)('E' - 'A')][(int)('E' - 'A')] = 0.263313634;	P_disordered[(int)('E' - 'A')][(int)('N' - 'A')] = 0.3446752575;	P_disordered[(int)('E' - 'A')][(int)('T' - 'A')] = 0.1291161889;	P_disordered[(int)('E' - 'A')][(int)('D' - 'A')] = -0.254654922;	P_disordered[(int)('E' - 'A')][(int)('V' - 'A')] = -0.163937304;	P_disordered[(int)('E' - 'A')][(int)('A' - 'A')] = -0.2181346024;	P_disordered[(int)('E' - 'A')][(int)('G' - 'A')] = -0.085254073;	P_disordered[(int)('E' - 'A')][(int)('R' - 'A')] = 0.072002458;	P_disordered[(int)('E' - 'A')][(int)('F' - 'A')] = -0.16965839;	P_disordered[(int)('E' - 'A')][(int)('P' - 'A')] = 0.042191088;	P_disordered[(int)('E' - 'A')][(int)('Q' - 'A')] = 0.08997119;	P_disordered[(int)('E' - 'A')][(int)('Y' - 'A')] = 0.0081852733;	P_disordered[(int)('E' - 'A')][(int)('H' - 'A')] = 0.14376688;	P_disordered[(int)('E' - 'A')][(int)('M' - 'A')] = 0.052235302;	P_disordered[(int)('E' - 'A')][(int)('C' - 'A')] = -0.003781184;	P_disordered[(int)('E' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('N' - 'A')][(int)('L' - 'A')] = -0.695738439;	P_disordered[(int)('N' - 'A')][(int)('S' - 'A')] = -0.2522602293;	P_disordered[(int)('N' - 'A')][(int)('K' - 'A')] = -0.104854888;	P_disordered[(int)('N' - 'A')][(int)('I' - 'A')] = 0.1431897193;	P_disordered[(int)('N' - 'A')][(int)('E' - 'A')] = -0.192187379;	P_disordered[(int)('N' - 'A')][(int)('N' - 'A')] = -0.3744525806;	P_disordered[(int)('N' - 'A')][(int)('T' - 'A')] = -0.1695538589;	P_disordered[(int)('N' - 'A')][(int)('D' - 'A')] = -0.078191381;	P_disordered[(int)('N' - 'A')][(int)('V' - 'A')] = 0.091049091;	P_disordered[(int)('N' - 'A')][(int)('A' - 'A')] = -0.0803711602;	P_disordered[(int)('N' - 'A')][(int)('G' - 'A')] = 0.007063771;	P_disordered[(int)('N' - 'A')][(int)('R' - 'A')] = -0.037425228;	P_disordered[(int)('N' - 'A')][(int)('F' - 'A')] = -0.04112118;	P_disordered[(int)('N' - 'A')][(int)('P' - 'A')] = -0.100732608;	P_disordered[(int)('N' - 'A')][(int)('Q' - 'A')] = 0.022055034;	P_disordered[(int)('N' - 'A')][(int)('Y' - 'A')] = 0.0010649659;	P_disordered[(int)('N' - 'A')][(int)('H' - 'A')] = 0.06954966;	P_disordered[(int)('N' - 'A')][(int)('M' - 'A')] = 0.030131765;	P_disordered[(int)('N' - 'A')][(int)('C' - 'A')] = -0.003629733;	P_disordered[(int)('N' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('T' - 'A')][(int)('L' - 'A')] = -0.225820147;	P_disordered[(int)('T' - 'A')][(int)('S' - 'A')] = 0.7475644602;	P_disordered[(int)('T' - 'A')][(int)('K' - 'A')] = -0.163361095;	P_disordered[(int)('T' - 'A')][(int)('I' - 'A')] = -0.0698634303;	P_disordered[(int)('T' - 'A')][(int)('E' - 'A')] = 0.2090753845;	P_disordered[(int)('T' - 'A')][(int)('N' - 'A')] = 0.0757325892;	P_disordered[(int)('T' - 'A')][(int)('T' - 'A')] = -0.3708878004;	P_disordered[(int)('T' - 'A')][(int)('D' - 'A')] = 0.056845233;	P_disordered[(int)('T' - 'A')][(int)('V' - 'A')] = 0.035431562;	P_disordered[(int)('T' - 'A')][(int)('A' - 'A')] = 0.0917443026;	P_disordered[(int)('T' - 'A')][(int)('G' - 'A')] = 0.066458684;	P_disordered[(int)('T' - 'A')][(int)('R' - 'A')] = -0.037691018;	P_disordered[(int)('T' - 'A')][(int)('F' - 'A')] = -0.01434142;	P_disordered[(int)('T' - 'A')][(int)('P' - 'A')] = -0.157436697;	P_disordered[(int)('T' - 'A')][(int)('Q' - 'A')] = -0.06878539;	P_disordered[(int)('T' - 'A')][(int)('Y' - 'A')] = -0.0002274669;	P_disordered[(int)('T' - 'A')][(int)('H' - 'A')] = -0.03166836;	P_disordered[(int)('T' - 'A')][(int)('M' - 'A')] = 0.03015909;	P_disordered[(int)('T' - 'A')][(int)('C' - 'A')] = -0.003526966;	P_disordered[(int)('T' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('D' - 'A')][(int)('L' - 'A')] = 0.293915361;	P_disordered[(int)('D' - 'A')][(int)('S' - 'A')] = 0.2625621171;	P_disordered[(int)('D' - 'A')][(int)('K' - 'A')] = 0.479659213;	P_disordered[(int)('D' - 'A')][(int)('I' - 'A')] = -0.2898773094;	P_disordered[(int)('D' - 'A')][(int)('E' - 'A')] = -0.2584483987;	P_disordered[(int)('D' - 'A')][(int)('N' - 'A')] = -0.1815736957;	P_disordered[(int)('D' - 'A')][(int)('T' - 'A')] = 0.0283218927;	P_disordered[(int)('D' - 'A')][(int)('D' - 'A')] = -0.287679959;	P_disordered[(int)('D' - 'A')][(int)('V' - 'A')] = -0.054016831;	P_disordered[(int)('D' - 'A')][(int)('A' - 'A')] = -0.3205939702;	P_disordered[(int)('D' - 'A')][(int)('G' - 'A')] = -0.053948183;	P_disordered[(int)('D' - 'A')][(int)('R' - 'A')] = 0.020023718;	P_disordered[(int)('D' - 'A')][(int)('F' - 'A')] = -0.17495999;	P_disordered[(int)('D' - 'A')][(int)('P' - 'A')] = -0.079804959;	P_disordered[(int)('D' - 'A')][(int)('Q' - 'A')] = 0.062852954;	P_disordered[(int)('D' - 'A')][(int)('Y' - 'A')] = 0.0048641021;	P_disordered[(int)('D' - 'A')][(int)('H' - 'A')] = 0.12046899;	P_disordered[(int)('D' - 'A')][(int)('M' - 'A')] = 0.043142543;	P_disordered[(int)('D' - 'A')][(int)('C' - 'A')] = -0.003803745;	P_disordered[(int)('D' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('V' - 'A')][(int)('L' - 'A')] = 0.019101245;	P_disordered[(int)('V' - 'A')][(int)('S' - 'A')] = 0.0990375464;	P_disordered[(int)('V' - 'A')][(int)('K' - 'A')] = -0.196074257;	P_disordered[(int)('V' - 'A')][(int)('I' - 'A')] = 0.2724294408;	P_disordered[(int)('V' - 'A')][(int)('E' - 'A')] = -0.6905140518;	P_disordered[(int)('V' - 'A')][(int)('N' - 'A')] = 0.404771219;	P_disordered[(int)('V' - 'A')][(int)('T' - 'A')] = 0.1338611695;	P_disordered[(int)('V' - 'A')][(int)('D' - 'A')] = -0.020086151;	P_disordered[(int)('V' - 'A')][(int)('V' - 'A')] = -0.107392867;	P_disordered[(int)('V' - 'A')][(int)('A' - 'A')] = 0.0946663944;	P_disordered[(int)('V' - 'A')][(int)('G' - 'A')] = 0.296269004;	P_disordered[(int)('V' - 'A')][(int)('R' - 'A')] = 0.281750362;	P_disordered[(int)('V' - 'A')][(int)('F' - 'A')] = -0.12645831;	P_disordered[(int)('V' - 'A')][(int)('P' - 'A')] = 0.011162552;	P_disordered[(int)('V' - 'A')][(int)('Q' - 'A')] = -0.216971247;	P_disordered[(int)('V' - 'A')][(int)('Y' - 'A')] = 0.0057456252;	P_disordered[(int)('V' - 'A')][(int)('H' - 'A')] = -0.19546943;	P_disordered[(int)('V' - 'A')][(int)('M' - 'A')] = 0.02010242;	P_disordered[(int)('V' - 'A')][(int)('C' - 'A')] = -0.003399857;	P_disordered[(int)('V' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('A' - 'A')][(int)('L' - 'A')] = -0.10790394;	P_disordered[(int)('A' - 'A')][(int)('S' - 'A')] = -0.4641371621;	P_disordered[(int)('A' - 'A')][(int)('K' - 'A')] = 0.556715789;	P_disordered[(int)('A' - 'A')][(int)('I' - 'A')] = -0.1845790751;	P_disordered[(int)('A' - 'A')][(int)('E' - 'A')] = 0.1329807305;	P_disordered[(int)('A' - 'A')][(int)('N' - 'A')] = 0.4787009118;	P_disordered[(int)('A' - 'A')][(int)('T' - 'A')] = -0.369097886;	P_disordered[(int)('A' - 'A')][(int)('D' - 'A')] = 0.121128154;	P_disordered[(int)('A' - 'A')][(int)('V' - 'A')] = -0.011472301;	P_disordered[(int)('A' - 'A')][(int)('A' - 'A')] = 0.0731006873;	P_disordered[(int)('A' - 'A')][(int)('G' - 'A')] = 0.079440383;	P_disordered[(int)('A' - 'A')][(int)('R' - 'A')] = -0.015479914;	P_disordered[(int)('A' - 'A')][(int)('F' - 'A')] = -0.01687299;	P_disordered[(int)('A' - 'A')][(int)('P' - 'A')] = -0.197102681;	P_disordered[(int)('A' - 'A')][(int)('Q' - 'A')] = -0.075682007;	P_disordered[(int)('A' - 'A')][(int)('Y' - 'A')] = -0.0002413739;	P_disordered[(int)('A' - 'A')][(int)('H' - 'A')] = -0.03779456;	P_disordered[(int)('A' - 'A')][(int)('M' - 'A')] = 0.031446384;	P_disordered[(int)('A' - 'A')][(int)('C' - 'A')] = -0.00356448;	P_disordered[(int)('A' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('G' - 'A')][(int)('L' - 'A')] = -0.062882096;	P_disordered[(int)('G' - 'A')][(int)('S' - 'A')] = 0.0785727927;	P_disordered[(int)('G' - 'A')][(int)('K' - 'A')] = 0.050084843;	P_disordered[(int)('G' - 'A')][(int)('I' - 'A')] = 0.0698456166;	P_disordered[(int)('G' - 'A')][(int)('E' - 'A')] = 0.0381248702;	P_disordered[(int)('G' - 'A')][(int)('N' - 'A')] = 0.0007942231;	P_disordered[(int)('G' - 'A')][(int)('T' - 'A')] = 0.4651861856;	P_disordered[(int)('G' - 'A')][(int)('D' - 'A')] = 0.81471085;	P_disordered[(int)('G' - 'A')][(int)('V' - 'A')] = 0.089115917;	P_disordered[(int)('G' - 'A')][(int)('A' - 'A')] = -0.2707738284;	P_disordered[(int)('G' - 'A')][(int)('G' - 'A')] = -0.050755459;	P_disordered[(int)('G' - 'A')][(int)('R' - 'A')] = -0.024767977;	P_disordered[(int)('G' - 'A')][(int)('F' - 'A')] = -0.16399679;	P_disordered[(int)('G' - 'A')][(int)('P' - 'A')] = -0.188295604;	P_disordered[(int)('G' - 'A')][(int)('Q' - 'A')] = 0.028753058;	P_disordered[(int)('G' - 'A')][(int)('Y' - 'A')] = 0.0002212104;	P_disordered[(int)('G' - 'A')][(int)('H' - 'A')] = 0.08067126;	P_disordered[(int)('G' - 'A')][(int)('M' - 'A')] = 0.04408228;	P_disordered[(int)('G' - 'A')][(int)('C' - 'A')] = -0.003560061;	P_disordered[(int)('G' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('R' - 'A')][(int)('L' - 'A')] = -0.079796252;	P_disordered[(int)('R' - 'A')][(int)('S' - 'A')] = -0.0438727345;	P_disordered[(int)('R' - 'A')][(int)('K' - 'A')] = -0.185104693;	P_disordered[(int)('R' - 'A')][(int)('I' - 'A')] = -0.6808835794;	P_disordered[(int)('R' - 'A')][(int)('E' - 'A')] = -0.1677872716;	P_disordered[(int)('R' - 'A')][(int)('N' - 'A')] = 0.0616876416;	P_disordered[(int)('R' - 'A')][(int)('T' - 'A')] = 0.1549658037;	P_disordered[(int)('R' - 'A')][(int)('D' - 'A')] = 0.062451108;	P_disordered[(int)('R' - 'A')][(int)('V' - 'A')] = 0.422863704;	P_disordered[(int)('R' - 'A')][(int)('A' - 'A')] = 0.4076299605;	P_disordered[(int)('R' - 'A')][(int)('G' - 'A')] = -0.030654921;	P_disordered[(int)('R' - 'A')][(int)('R' - 'A')] = 0.038312668;	P_disordered[(int)('R' - 'A')][(int)('F' - 'A')] = 0.01320318;	P_disordered[(int)('R' - 'A')][(int)('P' - 'A')] = 0.244580369;	P_disordered[(int)('R' - 'A')][(int)('Q' - 'A')] = 0.106523907;	P_disordered[(int)('R' - 'A')][(int)('Y' - 'A')] = 0.0065725436;	P_disordered[(int)('R' - 'A')][(int)('H' - 'A')] = 0.15079356;	P_disordered[(int)('R' - 'A')][(int)('M' - 'A')] = 0.046133296;	P_disordered[(int)('R' - 'A')][(int)('C' - 'A')] = -0.003033062;	P_disordered[(int)('R' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('F' - 'A')][(int)('L' - 'A')] = -0.023484941;	P_disordered[(int)('F' - 'A')][(int)('S' - 'A')] = 0.0090716857;	P_disordered[(int)('F' - 'A')][(int)('K' - 'A')] = 0.015897501;	P_disordered[(int)('F' - 'A')][(int)('I' - 'A')] = -0.0008776137;	P_disordered[(int)('F' - 'A')][(int)('E' - 'A')] = -0.0003829115;	P_disordered[(int)('F' - 'A')][(int)('N' - 'A')] = 0.0105630339;	P_disordered[(int)('F' - 'A')][(int)('T' - 'A')] = 0.0187541958;	P_disordered[(int)('F' - 'A')][(int)('D' - 'A')] = -0.003369438;	P_disordered[(int)('F' - 'A')][(int)('V' - 'A')] = -0.050900354;	P_disordered[(int)('F' - 'A')][(int)('A' - 'A')] = 0.0651086867;	P_disordered[(int)('F' - 'A')][(int)('G' - 'A')] = 0.122938919;	P_disordered[(int)('F' - 'A')][(int)('R' - 'A')] = -0.083778396;	P_disordered[(int)('F' - 'A')][(int)('F' - 'A')] = -0.16451265;	P_disordered[(int)('F' - 'A')][(int)('P' - 'A')] = -0.025977174;	P_disordered[(int)('F' - 'A')][(int)('Q' - 'A')] = 0.762086255;	P_disordered[(int)('F' - 'A')][(int)('Y' - 'A')] = 0.0109235818;	P_disordered[(int)('F' - 'A')][(int)('H' - 'A')] = -0.65131265;	P_disordered[(int)('F' - 'A')][(int)('M' - 'A')] = -0.306345477;	P_disordered[(int)('F' - 'A')][(int)('C' - 'A')] = -0.002489601;	P_disordered[(int)('F' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('P' - 'A')][(int)('L' - 'A')] = -0.163342707;	P_disordered[(int)('P' - 'A')][(int)('S' - 'A')] = 0.0681114104;	P_disordered[(int)('P' - 'A')][(int)('K' - 'A')] = 0.118650658;	P_disordered[(int)('P' - 'A')][(int)('I' - 'A')] = 0.0196072962;	P_disordered[(int)('P' - 'A')][(int)('E' - 'A')] = -0.0034430668;	P_disordered[(int)('P' - 'A')][(int)('N' - 'A')] = 0.0524911291;	P_disordered[(int)('P' - 'A')][(int)('T' - 'A')] = 0.5241291266;	P_disordered[(int)('P' - 'A')][(int)('D' - 'A')] = -0.23938101;	P_disordered[(int)('P' - 'A')][(int)('V' - 'A')] = -0.236862565;	P_disordered[(int)('P' - 'A')][(int)('A' - 'A')] = 0.2891631045;	P_disordered[(int)('P' - 'A')][(int)('G' - 'A')] = -0.091183908;	P_disordered[(int)('P' - 'A')][(int)('R' - 'A')] = -0.235574411;	P_disordered[(int)('P' - 'A')][(int)('F' - 'A')] = 0.33301139;	P_disordered[(int)('P' - 'A')][(int)('P' - 'A')] = -0.318489886;	P_disordered[(int)('P' - 'A')][(int)('Q' - 'A')] = -0.050648072;	P_disordered[(int)('P' - 'A')][(int)('Y' - 'A')] = -0.0026072645;	P_disordered[(int)('P' - 'A')][(int)('H' - 'A')] = -0.03905979;	P_disordered[(int)('P' - 'A')][(int)('M' - 'A')] = 0.024911266;	P_disordered[(int)('P' - 'A')][(int)('C' - 'A')] = -0.003447401;	P_disordered[(int)('P' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('Q' - 'A')][(int)('L' - 'A')] = 0.004403174;	P_disordered[(int)('Q' - 'A')][(int)('S' - 'A')] = 0.0148979937;	P_disordered[(int)('Q' - 'A')][(int)('K' - 'A')] = 0.04609596;	P_disordered[(int)('Q' - 'A')][(int)('I' - 'A')] = -0.0425505368;	P_disordered[(int)('Q' - 'A')][(int)('E' - 'A')] = -0.0818354792;	P_disordered[(int)('Q' - 'A')][(int)('N' - 'A')] = -0.1438043975;	P_disordered[(int)('Q' - 'A')][(int)('T' - 'A')] = -0.1991057409;	P_disordered[(int)('Q' - 'A')][(int)('D' - 'A')] = 0.290144963;	P_disordered[(int)('Q' - 'A')][(int)('V' - 'A')] = -0.690750811;	P_disordered[(int)('Q' - 'A')][(int)('A' - 'A')] = 0.1117114692;	P_disordered[(int)('Q' - 'A')][(int)('G' - 'A')] = -0.015338346;	P_disordered[(int)('Q' - 'A')][(int)('R' - 'A')] = 0.072600313;	P_disordered[(int)('Q' - 'A')][(int)('F' - 'A')] = 0.2150298;	P_disordered[(int)('Q' - 'A')][(int)('P' - 'A')] = 0.341993948;	P_disordered[(int)('Q' - 'A')][(int)('Q' - 'A')] = 0.129978017;	P_disordered[(int)('Q' - 'A')][(int)('Y' - 'A')] = 0.0119103261;	P_disordered[(int)('Q' - 'A')][(int)('H' - 'A')] = 0.16237162;	P_disordered[(int)('Q' - 'A')][(int)('M' - 'A')] = 0.042656748;	P_disordered[(int)('Q' - 'A')][(int)('C' - 'A')] = -0.003457905;	P_disordered[(int)('Q' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('Y' - 'A')][(int)('L' - 'A')] = -0.002707003;	P_disordered[(int)('Y' - 'A')][(int)('S' - 'A')] = 0.0063005135;	P_disordered[(int)('Y' - 'A')][(int)('K' - 'A')] = 0.006479847;	P_disordered[(int)('Y' - 'A')][(int)('I' - 'A')] = -0.0011506174;	P_disordered[(int)('Y' - 'A')][(int)('E' - 'A')] = 0.005502734;	P_disordered[(int)('Y' - 'A')][(int)('N' - 'A')] = 0.012027977;	P_disordered[(int)('Y' - 'A')][(int)('T' - 'A')] = 0.0066621233;	P_disordered[(int)('Y' - 'A')][(int)('D' - 'A')] = 0.008891009;	P_disordered[(int)('Y' - 'A')][(int)('V' - 'A')] = -0.030731851;	P_disordered[(int)('Y' - 'A')][(int)('A' - 'A')] = 0.0589833748;	P_disordered[(int)('Y' - 'A')][(int)('G' - 'A')] = -0.090424107;	P_disordered[(int)('Y' - 'A')][(int)('R' - 'A')] = 0.042481671;	P_disordered[(int)('Y' - 'A')][(int)('F' - 'A')] = -0.06105614;	P_disordered[(int)('Y' - 'A')][(int)('P' - 'A')] = -0.019069825;	P_disordered[(int)('Y' - 'A')][(int)('Q' - 'A')] = -0.272081238;	P_disordered[(int)('Y' - 'A')][(int)('Y' - 'A')] = 0.0300328094;	P_disordered[(int)('Y' - 'A')][(int)('H' - 'A')] = 0.37992235;	P_disordered[(int)('Y' - 'A')][(int)('M' - 'A')] = -0.931542481;	P_disordered[(int)('Y' - 'A')][(int)('C' - 'A')] = -0.002926891;	P_disordered[(int)('Y' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('H' - 'A')][(int)('L' - 'A')] = 0.060389979;	P_disordered[(int)('H' - 'A')][(int)('S' - 'A')] = 0.0336712206;	P_disordered[(int)('H' - 'A')][(int)('K' - 'A')] = 0.024267769;	P_disordered[(int)('H' - 'A')][(int)('I' - 'A')] = 0.0682303541;	P_disordered[(int)('H' - 'A')][(int)('E' - 'A')] = 0.0929075234;	P_disordered[(int)('H' - 'A')][(int)('N' - 'A')] = 0.1498834186;	P_disordered[(int)('H' - 'A')][(int)('T' - 'A')] = 0.1026527263;	P_disordered[(int)('H' - 'A')][(int)('D' - 'A')] = -0.074620329;	P_disordered[(int)('H' - 'A')][(int)('V' - 'A')] = 0.346465405;	P_disordered[(int)('H' - 'A')][(int)('A' - 'A')] = -0.5847393396;	P_disordered[(int)('H' - 'A')][(int)('G' - 'A')] = 0.779657541;	P_disordered[(int)('H' - 'A')][(int)('R' - 'A')] = -0.271356358;	P_disordered[(int)('H' - 'A')][(int)('F' - 'A')] = 0.62251145;	P_disordered[(int)('H' - 'A')][(int)('P' - 'A')] = 0.311017341;	P_disordered[(int)('H' - 'A')][(int)('Q' - 'A')] = 0.084959998;	P_disordered[(int)('H' - 'A')][(int)('Y' - 'A')] = 0.0091218311;	P_disordered[(int)('H' - 'A')][(int)('H' - 'A')] = 0.18446757;	P_disordered[(int)('H' - 'A')][(int)('M' - 'A')] = -0.053380706;	P_disordered[(int)('H' - 'A')][(int)('C' - 'A')] = -0.003524178;	P_disordered[(int)('H' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('M' - 'A')][(int)('L' - 'A')] = 0.008392739;	P_disordered[(int)('M' - 'A')][(int)('S' - 'A')] = -0.0373067922;	P_disordered[(int)('M' - 'A')][(int)('K' - 'A')] = -0.004752487;	P_disordered[(int)('M' - 'A')][(int)('I' - 'A')] = -0.0022679414;	P_disordered[(int)('M' - 'A')][(int)('E' - 'A')] = -0.0560056676;	P_disordered[(int)('M' - 'A')][(int)('N' - 'A')] = 0.0273282452;	P_disordered[(int)('M' - 'A')][(int)('T' - 'A')] = 0.0056791255;	P_disordered[(int)('M' - 'A')][(int)('D' - 'A')] = 0.01144829;	P_disordered[(int)('M' - 'A')][(int)('V' - 'A')] = -0.105985193;	P_disordered[(int)('M' - 'A')][(int)('A' - 'A')] = -0.0362919687;	P_disordered[(int)('M' - 'A')][(int)('G' - 'A')] = -0.100093334;	P_disordered[(int)('M' - 'A')][(int)('R' - 'A')] = -0.800869211;	P_disordered[(int)('M' - 'A')][(int)('F' - 'A')] = -0.43774261;	P_disordered[(int)('M' - 'A')][(int)('P' - 'A')] = 0.612471117;	P_disordered[(int)('M' - 'A')][(int)('Q' - 'A')] = -0.391589719;	P_disordered[(int)('M' - 'A')][(int)('Y' - 'A')] = 0.011847624;	P_disordered[(int)('M' - 'A')][(int)('H' - 'A')] = -0.31070665;	P_disordered[(int)('M' - 'A')][(int)('M' - 'A')] = 0.019803634;	P_disordered[(int)('M' - 'A')][(int)('C' - 'A')] = -0.003223404;	P_disordered[(int)('M' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('C' - 'A')][(int)('L' - 'A')] = -0.055075881;	P_disordered[(int)('C' - 'A')][(int)('S' - 'A')] = 0.0261307203;	P_disordered[(int)('C' - 'A')][(int)('K' - 'A')] = 0.048604417;	P_disordered[(int)('C' - 'A')][(int)('I' - 'A')] = 0.0094433249;	P_disordered[(int)('C' - 'A')][(int)('E' - 'A')] = 0.0121357571;	P_disordered[(int)('C' - 'A')][(int)('N' - 'A')] = 0.036470843;	P_disordered[(int)('C' - 'A')][(int)('T' - 'A')] = 0.0428303154;	P_disordered[(int)('C' - 'A')][(int)('D' - 'A')] = -0.030884739;	P_disordered[(int)('C' - 'A')][(int)('V' - 'A')] = -0.049797883;	P_disordered[(int)('C' - 'A')][(int)('A' - 'A')] = -0.0147478779;	P_disordered[(int)('C' - 'A')][(int)('G' - 'A')] = 0.00162633;	P_disordered[(int)('C' - 'A')][(int)('R' - 'A')] = 0.042452852;	P_disordered[(int)('C' - 'A')][(int)('F' - 'A')] = -0.04283289;	P_disordered[(int)('C' - 'A')][(int)('P' - 'A')] = 0.198362338;	P_disordered[(int)('C' - 'A')][(int)('Q' - 'A')] = 0.01710278;	P_disordered[(int)('C' - 'A')][(int)('Y' - 'A')] = -0.9991370042;	P_disordered[(int)('C' - 'A')][(int)('H' - 'A')] = 0.04110988;	P_disordered[(int)('C' - 'A')][(int)('M' - 'A')] = -0.130638819;	P_disordered[(int)('C' - 'A')][(int)('C' - 'A')] = -0.002014653;	P_disordered[(int)('C' - 'A')][(int)('W' - 'A')] = -0.2236068;
	P_disordered[(int)('W' - 'A')][(int)('L' - 'A')] = -0.002903426;	P_disordered[(int)('W' - 'A')][(int)('S' - 'A')] = 0.0009584729;	P_disordered[(int)('W' - 'A')][(int)('K' - 'A')] = 0.002843926;	P_disordered[(int)('W' - 'A')][(int)('I' - 'A')] = 0.0033704131;	P_disordered[(int)('W' - 'A')][(int)('E' - 'A')] = 0.0012729205;	P_disordered[(int)('W' - 'A')][(int)('N' - 'A')] = 0.0002918724;	P_disordered[(int)('W' - 'A')][(int)('T' - 'A')] = 0.0006120923;	P_disordered[(int)('W' - 'A')][(int)('D' - 'A')] = -0.003652942;	P_disordered[(int)('W' - 'A')][(int)('V' - 'A')] = -0.007961459;	P_disordered[(int)('W' - 'A')][(int)('A' - 'A')] = 0.0003218984;	P_disordered[(int)('W' - 'A')][(int)('G' - 'A')] = 0.009969426;	P_disordered[(int)('W' - 'A')][(int)('R' - 'A')] = -0.003941189;	P_disordered[(int)('W' - 'A')][(int)('F' - 'A')] = -0.01062756;	P_disordered[(int)('W' - 'A')][(int)('P' - 'A')] = -0.007693699;	P_disordered[(int)('W' - 'A')][(int)('Q' - 'A')] = 0.000635796;	P_disordered[(int)('W' - 'A')][(int)('Y' - 'A')] = 0.0015272568;	P_disordered[(int)('W' - 'A')][(int)('H' - 'A')] = 0.01523906;	P_disordered[(int)('W' - 'A')][(int)('M' - 'A')] = 0.006731747;	P_disordered[(int)('W' - 'A')][(int)('C' - 'A')] = 0.999897783;	P_disordered[(int)('W' - 'A')][(int)('W' - 'A')] = -0.2236068;

	P1_disordered[(int)('L' - 'A')][(int)('L' - 'A')] = -0.035215297;	P1_disordered[(int)('L' - 'A')][(int)('S' - 'A')] = 0.75139645;	P1_disordered[(int)('L' - 'A')][(int)('K' - 'A')] = 0.151501668;	P1_disordered[(int)('L' - 'A')][(int)('I' - 'A')] = 0.01463955;	P1_disordered[(int)('L' - 'A')][(int)('E' - 'A')] = -0.0859249;	P1_disordered[(int)('L' - 'A')][(int)('N' - 'A')] = -0.62207585;	P1_disordered[(int)('L' - 'A')][(int)('T' - 'A')] = -0.165111324;	P1_disordered[(int)('L' - 'A')][(int)('D' - 'A')] = 0.21636788;	P1_disordered[(int)('L' - 'A')][(int)('V' - 'A')] = 0.008705958;	P1_disordered[(int)('L' - 'A')][(int)('A' - 'A')] = -0.067076517;	P1_disordered[(int)('L' - 'A')][(int)('G' - 'A')] = -0.0321736329;	P1_disordered[(int)('L' - 'A')][(int)('R' - 'A')] = -0.0446568;	P1_disordered[(int)('L' - 'A')][(int)('F' - 'A')] = -0.0067313887;	P1_disordered[(int)('L' - 'A')][(int)('P' - 'A')] = -0.09928814;	P1_disordered[(int)('L' - 'A')][(int)('Q' - 'A')] = 0.002537099;	P1_disordered[(int)('L' - 'A')][(int)('Y' - 'A')] = -0.0006229545;	P1_disordered[(int)('L' - 'A')][(int)('H' - 'A')] = 0.014404116;	P1_disordered[(int)('L' - 'A')][(int)('M' - 'A')] = 0.0020511732;	P1_disordered[(int)('L' - 'A')][(int)('C' - 'A')] = -0.0026172505;	P1_disordered[(int)('L' - 'A')][(int)('W' - 'A')] = -0.0001098477;
	P1_disordered[(int)('S' - 'A')][(int)('L' - 'A')] = 0.020131384;	P1_disordered[(int)('S' - 'A')][(int)('S' - 'A')] = -0.33962683;	P1_disordered[(int)('S' - 'A')][(int)('K' - 'A')] = 0.09151184;	P1_disordered[(int)('S' - 'A')][(int)('I' - 'A')] = -0.08523711;	P1_disordered[(int)('S' - 'A')][(int)('E' - 'A')] = -0.15178983;	P1_disordered[(int)('S' - 'A')][(int)('N' - 'A')] = -0.30773985;	P1_disordered[(int)('S' - 'A')][(int)('T' - 'A')] = 0.745762384;	P1_disordered[(int)('S' - 'A')][(int)('D' - 'A')] = 0.26371825;	P1_disordered[(int)('S' - 'A')][(int)('V' - 'A')] = 0.06158749;	P1_disordered[(int)('S' - 'A')][(int)('A' - 'A')] = -0.39365631;	P1_disordered[(int)('S' - 'A')][(int)('G' - 'A')] = 0.0548508234;	P1_disordered[(int)('S' - 'A')][(int)('R' - 'A')] = -0.03349945;	P1_disordered[(int)('S' - 'A')][(int)('F' - 'A')] = 0.0035476504;	P1_disordered[(int)('S' - 'A')][(int)('P' - 'A')] = 0.05648786;	P1_disordered[(int)('S' - 'A')][(int)('Q' - 'A')] = 0.011712179;	P1_disordered[(int)('S' - 'A')][(int)('Y' - 'A')] = 0.0019782531;	P1_disordered[(int)('S' - 'A')][(int)('H' - 'A')] = 0.01095767;	P1_disordered[(int)('S' - 'A')][(int)('M' - 'A')] = -0.0124401118;	P1_disordered[(int)('S' - 'A')][(int)('C' - 'A')] = 0.0016942319;	P1_disordered[(int)('S' - 'A')][(int)('W' - 'A')] = 0.00004947636;
	P1_disordered[(int)('K' - 'A')][(int)('L' - 'A')] = 0.034523039;	P1_disordered[(int)('K' - 'A')][(int)('S' - 'A')] = -0.53883902;	P1_disordered[(int)('K' - 'A')][(int)('K' - 'A')] = 0.340230183;	P1_disordered[(int)('K' - 'A')][(int)('I' - 'A')] = 0.06848369;	P1_disordered[(int)('K' - 'A')][(int)('E' - 'A')] = -0.45376549;	P1_disordered[(int)('K' - 'A')][(int)('N' - 'A')] = -0.11966147;	P1_disordered[(int)('K' - 'A')][(int)('T' - 'A')] = -0.152451213;	P1_disordered[(int)('K' - 'A')][(int)('D' - 'A')] = 0.4506832;	P1_disordered[(int)('K' - 'A')][(int)('V' - 'A')] = -0.114062706;	P1_disordered[(int)('K' - 'A')][(int)('A' - 'A')] = 0.441707638;	P1_disordered[(int)('K' - 'A')][(int)('G' - 'A')] = 0.0327075251;	P1_disordered[(int)('K' - 'A')][(int)('R' - 'A')] = -0.13221807;	P1_disordered[(int)('K' - 'A')][(int)('F' - 'A')] = 0.0058158363;	P1_disordered[(int)('K' - 'A')][(int)('P' - 'A')] = 0.09205257;	P1_disordered[(int)('K' - 'A')][(int)('Q' - 'A')] = 0.033900265;	P1_disordered[(int)('K' - 'A')][(int)('Y' - 'A')] = 0.0019032732;	P1_disordered[(int)('K' - 'A')][(int)('H' - 'A')] = 0.007387884;	P1_disordered[(int)('K' - 'A')][(int)('M' - 'A')] = -0.0014824804;	P1_disordered[(int)('K' - 'A')][(int)('C' - 'A')] = 0.002948002;	P1_disordered[(int)('K' - 'A')][(int)('W' - 'A')] = 0.0001373305;
	P1_disordered[(int)('I' - 'A')][(int)('L' - 'A')] = 0.001741903;	P1_disordered[(int)('I' - 'A')][(int)('S' - 'A')] = 0.05537634;	P1_disordered[(int)('I' - 'A')][(int)('K' - 'A')] = 0.755921508;	P1_disordered[(int)('I' - 'A')][(int)('I' - 'A')] = -0.12517889;	P1_disordered[(int)('I' - 'A')][(int)('E' - 'A')] = -0.01321998;	P1_disordered[(int)('I' - 'A')][(int)('N' - 'A')] = 0.18410705;	P1_disordered[(int)('I' - 'A')][(int)('T' - 'A')] = -0.073455675;	P1_disordered[(int)('I' - 'A')][(int)('D' - 'A')] = -0.3068642;	P1_disordered[(int)('I' - 'A')][(int)('V' - 'A')] = 0.178554331;	P1_disordered[(int)('I' - 'A')][(int)('A' - 'A')] = -0.164997388;	P1_disordered[(int)('I' - 'A')][(int)('G' - 'A')] = 0.051389496;	P1_disordered[(int)('I' - 'A')][(int)('R' - 'A')] = -0.54794823;	P1_disordered[(int)('I' - 'A')][(int)('F' - 'A')] = -0.0003617248;	P1_disordered[(int)('I' - 'A')][(int)('P' - 'A')] = 0.0171387;	P1_disordered[(int)('I' - 'A')][(int)('Q' - 'A')] = -0.035256537;	P1_disordered[(int)('I' - 'A')][(int)('Y' - 'A')] = -0.0003807667;	P1_disordered[(int)('I' - 'A')][(int)('H' - 'A')] = 0.02340244;	P1_disordered[(int)('I' - 'A')][(int)('M' - 'A')] = -0.0007970671;	P1_disordered[(int)('I' - 'A')][(int)('C' - 'A')] = 0.0006453142;	P1_disordered[(int)('I' - 'A')][(int)('W' - 'A')] = 0.0001833687;
	P1_disordered[(int)('E' - 'A')][(int)('L' - 'A')] = 0.016984814;	P1_disordered[(int)('E' - 'A')][(int)('S' - 'A')] = -0.07465288;	P1_disordered[(int)('E' - 'A')][(int)('K' - 'A')] = 0.196757447;	P1_disordered[(int)('E' - 'A')][(int)('I' - 'A')] = 0.42882265;	P1_disordered[(int)('E' - 'A')][(int)('E' - 'A')] = 0.43048105;	P1_disordered[(int)('E' - 'A')][(int)('N' - 'A')] = -0.30930506;	P1_disordered[(int)('E' - 'A')][(int)('T' - 'A')] = 0.275157908;	P1_disordered[(int)('E' - 'A')][(int)('D' - 'A')] = -0.34245953;	P1_disordered[(int)('E' - 'A')][(int)('V' - 'A')] = -0.566490248;	P1_disordered[(int)('E' - 'A')][(int)('A' - 'A')] = 0.148794454;	P1_disordered[(int)('E' - 'A')][(int)('G' - 'A')] = 0.0351113012;	P1_disordered[(int)('E' - 'A')][(int)('R' - 'A')] = -0.16901661;	P1_disordered[(int)('E' - 'A')][(int)('F' - 'A')] = -0.0001975512;	P1_disordered[(int)('E' - 'A')][(int)('P' - 'A')] = -0.0037671;	P1_disordered[(int)('E' - 'A')][(int)('Q' - 'A')] = -0.08487484;	P1_disordered[(int)('E' - 'A')][(int)('Y' - 'A')] = 0.0022793543;	P1_disordered[(int)('E' - 'A')][(int)('H' - 'A')] = 0.03988757;	P1_disordered[(int)('E' - 'A')][(int)('M' - 'A')] = -0.0246374599;	P1_disordered[(int)('E' - 'A')][(int)('C' - 'A')] = 0.0010380443;	P1_disordered[(int)('E' - 'A')][(int)('W' - 'A')] = 0.00008668557;
	P1_disordered[(int)('N' - 'A')][(int)('L' - 'A')] = 0.041232812;	P1_disordered[(int)('N' - 'A')][(int)('S' - 'A')] = -0.31270349;	P1_disordered[(int)('N' - 'A')][(int)('K' - 'A')] = 0.003245836;	P1_disordered[(int)('N' - 'A')][(int)('I' - 'A')] = -0.37378612;	P1_disordered[(int)('N' - 'A')][(int)('E' - 'A')] = 0.48318291;	P1_disordered[(int)('N' - 'A')][(int)('N' - 'A')] = -0.51674918;	P1_disordered[(int)('N' - 'A')][(int)('T' - 'A')] = 0.085463854;	P1_disordered[(int)('N' - 'A')][(int)('D' - 'A')] = -0.20630465;	P1_disordered[(int)('N' - 'A')][(int)('V' - 'A')] = 0.284741252;	P1_disordered[(int)('N' - 'A')][(int)('A' - 'A')] = 0.459286017;	P1_disordered[(int)('N' - 'A')][(int)('G' - 'A')] = 0.0006271582;	P1_disordered[(int)('N' - 'A')][(int)('R' - 'A')] = 0.05328295;	P1_disordered[(int)('N' - 'A')][(int)('F' - 'A')] = 0.0046729329;	P1_disordered[(int)('N' - 'A')][(int)('P' - 'A')] = 0.04924578;	P1_disordered[(int)('N' - 'A')][(int)('Q' - 'A')] = -0.127888104;	P1_disordered[(int)('N' - 'A')][(int)('Y' - 'A')] = 0.0042721511;	P1_disordered[(int)('N' - 'A')][(int)('H' - 'A')] = 0.05517737;	P1_disordered[(int)('N' - 'A')][(int)('M' - 'A')] = 0.0103085329;	P1_disordered[(int)('N' - 'A')][(int)('C' - 'A')] = 0.0026749484;	P1_disordered[(int)('N' - 'A')][(int)('W' - 'A')] = 0.00001704354;
	P1_disordered[(int)('T' - 'A')][(int)('L' - 'A')] = -0.045953161;	P1_disordered[(int)('T' - 'A')][(int)('S' - 'A')] = -0.36604651;	P1_disordered[(int)('T' - 'A')][(int)('K' - 'A')] = 0.028607274;	P1_disordered[(int)('T' - 'A')][(int)('I' - 'A')] = 0.20631587;	P1_disordered[(int)('T' - 'A')][(int)('E' - 'A')] = 0.18817909;	P1_disordered[(int)('T' - 'A')][(int)('N' - 'A')] = -0.24326491;	P1_disordered[(int)('T' - 'A')][(int)('T' - 'A')] = -0.435142371;	P1_disordered[(int)('T' - 'A')][(int)('D' - 'A')] = 0.0334556;	P1_disordered[(int)('T' - 'A')][(int)('V' - 'A')] = 0.097900297;	P1_disordered[(int)('T' - 'A')][(int)('A' - 'A')] = -0.368170913;	P1_disordered[(int)('T' - 'A')][(int)('G' - 'A')] = 0.3819218652;	P1_disordered[(int)('T' - 'A')][(int)('R' - 'A')] = 0.13916024;	P1_disordered[(int)('T' - 'A')][(int)('F' - 'A')] = 0.0086255773;	P1_disordered[(int)('T' - 'A')][(int)('P' - 'A')] = 0.51122327;	P1_disordered[(int)('T' - 'A')][(int)('Q' - 'A')] = -0.184090224;	P1_disordered[(int)('T' - 'A')][(int)('Y' - 'A')] = 0.0024601141;	P1_disordered[(int)('T' - 'A')][(int)('H' - 'A')] = 0.039288628;	P1_disordered[(int)('T' - 'A')][(int)('M' - 'A')] = 0.0022271621;	P1_disordered[(int)('T' - 'A')][(int)('C' - 'A')] = 0.0032659515;	P1_disordered[(int)('T' - 'A')][(int)('W' - 'A')] = 0.00003715971;
	P1_disordered[(int)('D' - 'A')][(int)('L' - 'A')] = 0.009522143;	P1_disordered[(int)('D' - 'A')][(int)('S' - 'A')] = 0.08718747;	P1_disordered[(int)('D' - 'A')][(int)('K' - 'A')] = -0.121657845;	P1_disordered[(int)('D' - 'A')][(int)('I' - 'A')] = -0.06693745;	P1_disordered[(int)('D' - 'A')][(int)('E' - 'A')] = -0.40355869;	P1_disordered[(int)('D' - 'A')][(int)('N' - 'A')] = -0.12198167;	P1_disordered[(int)('D' - 'A')][(int)('T' - 'A')] = 0.072518353;	P1_disordered[(int)('D' - 'A')][(int)('D' - 'A')] = -0.36950373;	P1_disordered[(int)('D' - 'A')][(int)('V' - 'A')] = -0.015973184;	P1_disordered[(int)('D' - 'A')][(int)('A' - 'A')] = 0.131376471;	P1_disordered[(int)('D' - 'A')][(int)('G' - 'A')] = 0.7273037403;	P1_disordered[(int)('D' - 'A')][(int)('R' - 'A')] = 0.06097949;	P1_disordered[(int)('D' - 'A')][(int)('F' - 'A')] = -0.0016850492;	P1_disordered[(int)('D' - 'A')][(int)('P' - 'A')] = -0.25387904;	P1_disordered[(int)('D' - 'A')][(int)('Q' - 'A')] = 0.291693204;	P1_disordered[(int)('D' - 'A')][(int)('Y' - 'A')] = 0.0035699171;	P1_disordered[(int)('D' - 'A')][(int)('H' - 'A')] = -0.03105404;	P1_disordered[(int)('D' - 'A')][(int)('M' - 'A')] = 0.0048817889;	P1_disordered[(int)('D' - 'A')][(int)('C' - 'A')] = -0.0025607499;	P1_disordered[(int)('D' - 'A')][(int)('W' - 'A')] = -0.0002411361;
	P1_disordered[(int)('V' - 'A')][(int)('L' - 'A')] = 0.237309052;	P1_disordered[(int)('V' - 'A')][(int)('S' - 'A')] = 0.09476912;	P1_disordered[(int)('V' - 'A')][(int)('K' - 'A')] = 0.395080871;	P1_disordered[(int)('V' - 'A')][(int)('I' - 'A')] = -0.08280599;	P1_disordered[(int)('V' - 'A')][(int)('E' - 'A')] = -0.26303072;	P1_disordered[(int)('V' - 'A')][(int)('N' - 'A')] = 0.143809;	P1_disordered[(int)('V' - 'A')][(int)('T' - 'A')] = 0.045763343;	P1_disordered[(int)('V' - 'A')][(int)('D' - 'A')] = -0.07024445;	P1_disordered[(int)('V' - 'A')][(int)('V' - 'A')] = -0.086465666;	P1_disordered[(int)('V' - 'A')][(int)('A' - 'A')] = -0.01259785;	P1_disordered[(int)('V' - 'A')][(int)('G' - 'A')] = 0.0805456242;	P1_disordered[(int)('V' - 'A')][(int)('R' - 'A')] = 0.41804054;	P1_disordered[(int)('V' - 'A')][(int)('F' - 'A')] = -0.0257720572;	P1_disordered[(int)('V' - 'A')][(int)('P' - 'A')] = -0.25433564;	P1_disordered[(int)('V' - 'A')][(int)('Q' - 'A')] = -0.703083144;	P1_disordered[(int)('V' - 'A')][(int)('Y' - 'A')] = -0.0124930962;	P1_disordered[(int)('V' - 'A')][(int)('H' - 'A')] = 0.145980383;	P1_disordered[(int)('V' - 'A')][(int)('M' - 'A')] = -0.0457569187;	P1_disordered[(int)('V' - 'A')][(int)('C' - 'A')] = -0.0041803045;	P1_disordered[(int)('V' - 'A')][(int)('W' - 'A')] = -0.0005320913;
	P1_disordered[(int)('A' - 'A')][(int)('L' - 'A')] = -0.36866321;	P1_disordered[(int)('A' - 'A')][(int)('S' - 'A')] = 0.0726601;	P1_disordered[(int)('A' - 'A')][(int)('K' - 'A')] = 0.451951907;	P1_disordered[(int)('A' - 'A')][(int)('I' - 'A')] = 0.10691502;	P1_disordered[(int)('A' - 'A')][(int)('E' - 'A')] = -0.37903676;	P1_disordered[(int)('A' - 'A')][(int)('N' - 'A')] = -0.13747973;	P1_disordered[(int)('A' - 'A')][(int)('T' - 'A')] = 0.128331878;	P1_disordered[(int)('A' - 'A')][(int)('D' - 'A')] = -0.45150946;	P1_disordered[(int)('A' - 'A')][(int)('V' - 'A')] = 0.082545371;	P1_disordered[(int)('A' - 'A')][(int)('A' - 'A')] = 0.086935247;	P1_disordered[(int)('A' - 'A')][(int)('G' - 'A')] = -0.265046171;	P1_disordered[(int)('A' - 'A')][(int)('R' - 'A')] = 0.43642775;	P1_disordered[(int)('A' - 'A')][(int)('F' - 'A')] = 0.0357022125;	P1_disordered[(int)('A' - 'A')][(int)('P' - 'A')] = 0.33626499;	P1_disordered[(int)('A' - 'A')][(int)('Q' - 'A')] = 0.123143529;	P1_disordered[(int)('A' - 'A')][(int)('Y' - 'A')] = 0.0259680543;	P1_disordered[(int)('A' - 'A')][(int)('H' - 'A')] = -0.2668243;	P1_disordered[(int)('A' - 'A')][(int)('M' - 'A')] = -0.0169689599;	P1_disordered[(int)('A' - 'A')][(int)('C' - 'A')] = -0.0013407695;	P1_disordered[(int)('A' - 'A')][(int)('W' - 'A')] = 0.00002329919;
	P1_disordered[(int)('G' - 'A')][(int)('L' - 'A')] = -0.742775226;	P1_disordered[(int)('G' - 'A')][(int)('S' - 'A')] = -0.04235509;	P1_disordered[(int)('G' - 'A')][(int)('K' - 'A')] = -0.157723127;	P1_disordered[(int)('G' - 'A')][(int)('I' - 'A')] = 0.42831292;	P1_disordered[(int)('G' - 'A')][(int)('E' - 'A')] = -0.20841651;	P1_disordered[(int)('G' - 'A')][(int)('N' - 'A')] = 0.01699892;	P1_disordered[(int)('G' - 'A')][(int)('T' - 'A')] = 0.130788122;	P1_disordered[(int)('G' - 'A')][(int)('D' - 'A')] = -0.10689316;	P1_disordered[(int)('G' - 'A')][(int)('V' - 'A')] = 0.363452894;	P1_disordered[(int)('G' - 'A')][(int)('A' - 'A')] = 0.132916247;	P1_disordered[(int)('G' - 'A')][(int)('G' - 'A')] = -0.0698975251;	P1_disordered[(int)('G' - 'A')][(int)('R' - 'A')] = -0.0461749;	P1_disordered[(int)('G' - 'A')][(int)('F' - 'A')] = 0.0948432381;	P1_disordered[(int)('G' - 'A')][(int)('P' - 'A')] = -0.14918588;	P1_disordered[(int)('G' - 'A')][(int)('Q' - 'A')] = -0.023786946;	P1_disordered[(int)('G' - 'A')][(int)('Y' - 'A')] = -0.0560086509;	P1_disordered[(int)('G' - 'A')][(int)('H' - 'A')] = 0.500528049;	P1_disordered[(int)('G' - 'A')][(int)('M' - 'A')] = -0.0658466383;	P1_disordered[(int)('G' - 'A')][(int)('C' - 'A')] = 0.0002080523;	P1_disordered[(int)('G' - 'A')][(int)('W' - 'A')] = 0.001015204;
	P1_disordered[(int)('R' - 'A')][(int)('L' - 'A')] = 0.417719237;	P1_disordered[(int)('R' - 'A')][(int)('S' - 'A')] = -0.29529052;	P1_disordered[(int)('R' - 'A')][(int)('K' - 'A')] = 0.128649849;	P1_disordered[(int)('R' - 'A')][(int)('I' - 'A')] = 0.42970838;	P1_disordered[(int)('R' - 'A')][(int)('E' - 'A')] = 0.19569475;	P1_disordered[(int)('R' - 'A')][(int)('N' - 'A')] = -0.10013405;	P1_disordered[(int)('R' - 'A')][(int)('T' - 'A')] = -0.082464463;	P1_disordered[(int)('R' - 'A')][(int)('D' - 'A')] = 0.04410874;	P1_disordered[(int)('R' - 'A')][(int)('V' - 'A')] = 0.38427527;	P1_disordered[(int)('R' - 'A')][(int)('A' - 'A')] = -0.028794325;	P1_disordered[(int)('R' - 'A')][(int)('G' - 'A')] = -0.0379219982;	P1_disordered[(int)('R' - 'A')][(int)('R' - 'A')] = 0.06416033;	P1_disordered[(int)('R' - 'A')][(int)('F' - 'A')] = -0.0718559751;	P1_disordered[(int)('R' - 'A')][(int)('P' - 'A')] = -0.42849593;	P1_disordered[(int)('R' - 'A')][(int)('Q' - 'A')] = 0.125178785;	P1_disordered[(int)('R' - 'A')][(int)('Y' - 'A')] = 0.0292539194;	P1_disordered[(int)('R' - 'A')][(int)('H' - 'A')] = -0.193675082;	P1_disordered[(int)('R' - 'A')][(int)('M' - 'A')] = -0.5857075859;	P1_disordered[(int)('R' - 'A')][(int)('C' - 'A')] = 0.0060368581;	P1_disordered[(int)('R' - 'A')][(int)('W' - 'A')] = -0.0004461909;
	P1_disordered[(int)('F' - 'A')][(int)('L' - 'A')] = 0.586161115;	P1_disordered[(int)('F' - 'A')][(int)('S' - 'A')] = 0.16837501;	P1_disordered[(int)('F' - 'A')][(int)('K' - 'A')] = -0.157586899;	P1_disordered[(int)('F' - 'A')][(int)('I' - 'A')] = -0.17724495;	P1_disordered[(int)('F' - 'A')][(int)('E' - 'A')] = -0.37906388;	P1_disordered[(int)('F' - 'A')][(int)('N' - 'A')] = -0.09044493;	P1_disordered[(int)('F' - 'A')][(int)('T' - 'A')] = -0.025794617;	P1_disordered[(int)('F' - 'A')][(int)('D' - 'A')] = -0.31683306;	P1_disordered[(int)('F' - 'A')][(int)('V' - 'A')] = -0.141782811;	P1_disordered[(int)('F' - 'A')][(int)('A' - 'A')] = -0.025801681;	P1_disordered[(int)('F' - 'A')][(int)('G' - 'A')] = -0.2064098797;	P1_disordered[(int)('F' - 'A')][(int)('R' - 'A')] = 0.01817629;	P1_disordered[(int)('F' - 'A')][(int)('F' - 'A')] = -0.1159941171;	P1_disordered[(int)('F' - 'A')][(int)('P' - 'A')] = 0.49794138;	P1_disordered[(int)('F' - 'A')][(int)('Q' - 'A')] = 0.304784209;	P1_disordered[(int)('F' - 'A')][(int)('Y' - 'A')] = -0.0345636279;	P1_disordered[(int)('F' - 'A')][(int)('H' - 'A')] = 0.365250272;	P1_disordered[(int)('F' - 'A')][(int)('M' - 'A')] = -0.2631716808;	P1_disordered[(int)('F' - 'A')][(int)('C' - 'A')] = -0.0050070561;	P1_disordered[(int)('F' - 'A')][(int)('W' - 'A')] = -0.0009890894;
	P1_disordered[(int)('P' - 'A')][(int)('L' - 'A')] = 0.283715247;	P1_disordered[(int)('P' - 'A')][(int)('S' - 'A')] = -0.55414754;	P1_disordered[(int)('P' - 'A')][(int)('K' - 'A')] = 0.35874858;	P1_disordered[(int)('P' - 'A')][(int)('I' - 'A')] = 0.08467557;	P1_disordered[(int)('P' - 'A')][(int)('E' - 'A')] = 0.0851237;	P1_disordered[(int)('P' - 'A')][(int)('N' - 'A')] = -0.20006985;	P1_disordered[(int)('P' - 'A')][(int)('T' - 'A')] = -0.255702152;	P1_disordered[(int)('P' - 'A')][(int)('D' - 'A')] = -0.1305012;	P1_disordered[(int)('P' - 'A')][(int)('V' - 'A')] = 0.01130135;	P1_disordered[(int)('P' - 'A')][(int)('A' - 'A')] = -0.272169828;	P1_disordered[(int)('P' - 'A')][(int)('G' - 'A')] = -0.214006902;	P1_disordered[(int)('P' - 'A')][(int)('R' - 'A')] = 0.30404705;	P1_disordered[(int)('P' - 'A')][(int)('F' - 'A')] = -0.0165394722;	P1_disordered[(int)('P' - 'A')][(int)('P' - 'A')] = -0.43003861;	P1_disordered[(int)('P' - 'A')][(int)('Q' - 'A')] = 0.437728569;	P1_disordered[(int)('P' - 'A')][(int)('Y' - 'A')] = -0.0097483089;	P1_disordered[(int)('P' - 'A')][(int)('H' - 'A')] = 0.164786035;	P1_disordered[(int)('P' - 'A')][(int)('M' - 'A')] = 0.3325052903;	P1_disordered[(int)('P' - 'A')][(int)('C' - 'A')] = 0.0209390653;	P1_disordered[(int)('P' - 'A')][(int)('W' - 'A')] = -0.0006465915;
	P1_disordered[(int)('Q' - 'A')][(int)('L' - 'A')] = -0.272034345;	P1_disordered[(int)('Q' - 'A')][(int)('S' - 'A')] = -0.09124336;	P1_disordered[(int)('Q' - 'A')][(int)('K' - 'A')] = 0.275729019;	P1_disordered[(int)('Q' - 'A')][(int)('I' - 'A')] = -0.37127303;	P1_disordered[(int)('Q' - 'A')][(int)('E' - 'A')] = 0.24809645;	P1_disordered[(int)('Q' - 'A')][(int)('N' - 'A')] = 0.05986957;	P1_disordered[(int)('Q' - 'A')][(int)('T' - 'A')] = -0.152690474;	P1_disordered[(int)('Q' - 'A')][(int)('D' - 'A')] = 0.14047447;	P1_disordered[(int)('Q' - 'A')][(int)('V' - 'A')] = -0.300233071;	P1_disordered[(int)('Q' - 'A')][(int)('A' - 'A')] = -0.142832602;	P1_disordered[(int)('Q' - 'A')][(int)('G' - 'A')] = 0.0446641415;	P1_disordered[(int)('Q' - 'A')][(int)('R' - 'A')] = 0.18098958;	P1_disordered[(int)('Q' - 'A')][(int)('F' - 'A')] = 0.6631636592;	P1_disordered[(int)('Q' - 'A')][(int)('P' - 'A')] = -0.09346785;	P1_disordered[(int)('Q' - 'A')][(int)('Q' - 'A')] = 0.227375461;	P1_disordered[(int)('Q' - 'A')][(int)('Y' - 'A')] = -0.1900939725;	P1_disordered[(int)('Q' - 'A')][(int)('H' - 'A')] = 0.061523002;	P1_disordered[(int)('Q' - 'A')][(int)('M' - 'A')] = -0.2905571484;	P1_disordered[(int)('Q' - 'A')][(int)('C' - 'A')] = 0.0024674668;	P1_disordered[(int)('Q' - 'A')][(int)('W' - 'A')] = 0.0000730299;
	P1_disordered[(int)('Y' - 'A')][(int)('L' - 'A')] = 0.092000454;	P1_disordered[(int)('Y' - 'A')][(int)('S' - 'A')] = -0.13708613;	P1_disordered[(int)('Y' - 'A')][(int)('K' - 'A')] = 0.162867027;	P1_disordered[(int)('Y' - 'A')][(int)('I' - 'A')] = 0.06877168;	P1_disordered[(int)('Y' - 'A')][(int)('E' - 'A')] = 0.15462897;	P1_disordered[(int)('Y' - 'A')][(int)('N' - 'A')] = 0.01980499;	P1_disordered[(int)('Y' - 'A')][(int)('T' - 'A')] = -0.003459192;	P1_disordered[(int)('Y' - 'A')][(int)('D' - 'A')] = 0.07447577;	P1_disordered[(int)('Y' - 'A')][(int)('V' - 'A')] = 0.054467091;	P1_disordered[(int)('Y' - 'A')][(int)('A' - 'A')] = -0.003120801;	P1_disordered[(int)('Y' - 'A')][(int)('G' - 'A')] = 0.0023540962;	P1_disordered[(int)('Y' - 'A')][(int)('R' - 'A')] = 0.07650338;	P1_disordered[(int)('Y' - 'A')][(int)('F' - 'A')] = 0.0651212002;	P1_disordered[(int)('Y' - 'A')][(int)('P' - 'A')] = -0.03296285;	P1_disordered[(int)('Y' - 'A')][(int)('Q' - 'A')] = 0.142737455;	P1_disordered[(int)('Y' - 'A')][(int)('Y' - 'A')] = 0.1437494881;	P1_disordered[(int)('Y' - 'A')][(int)('H' - 'A')] = 0.045252832;	P1_disordered[(int)('Y' - 'A')][(int)('M' - 'A')] = 0.0602243428;	P1_disordered[(int)('Y' - 'A')][(int)('C' - 'A')] = -0.9875316019;	P1_disordered[(int)('Y' - 'A')][(int)('W' - 'A')] = 0.001201806;
	P1_disordered[(int)('H' - 'A')][(int)('L' - 'A')] = -0.588617235;	P1_disordered[(int)('H' - 'A')][(int)('S' - 'A')] = -0.02783951;	P1_disordered[(int)('H' - 'A')][(int)('K' - 'A')] = 0.36105155;	P1_disordered[(int)('H' - 'A')][(int)('I' - 'A')] = -0.2967944;	P1_disordered[(int)('H' - 'A')][(int)('E' - 'A')] = 0.33927344;	P1_disordered[(int)('H' - 'A')][(int)('N' - 'A')] = 0.16157254;	P1_disordered[(int)('H' - 'A')][(int)('T' - 'A')] = -0.060161032;	P1_disordered[(int)('H' - 'A')][(int)('D' - 'A')] = 0.23042041;	P1_disordered[(int)('H' - 'A')][(int)('V' - 'A')] = -0.231477697;	P1_disordered[(int)('H' - 'A')][(int)('A' - 'A')] = -0.061043284;	P1_disordered[(int)('H' - 'A')][(int)('G' - 'A')] = 0.1072426936;	P1_disordered[(int)('H' - 'A')][(int)('R' - 'A')] = 0.21926191;	P1_disordered[(int)('H' - 'A')][(int)('F' - 'A')] = -0.4850427897;	P1_disordered[(int)('H' - 'A')][(int)('P' - 'A')] = -0.06168835;	P1_disordered[(int)('H' - 'A')][(int)('Q' - 'A')] = 0.243084767;	P1_disordered[(int)('H' - 'A')][(int)('Y' - 'A')] = 0.2271635003;	P1_disordered[(int)('H' - 'A')][(int)('H' - 'A')] = 0.114318625;	P1_disordered[(int)('H' - 'A')][(int)('M' - 'A')] = -0.1972989463;	P1_disordered[(int)('H' - 'A')][(int)('C' - 'A')] = 0.0050758111;	P1_disordered[(int)('H' - 'A')][(int)('W' - 'A')] = 0.001498007;
	P1_disordered[(int)('M' - 'A')][(int)('L' - 'A')] = -0.069275734;	P1_disordered[(int)('M' - 'A')][(int)('S' - 'A')] = 0.12173435;	P1_disordered[(int)('M' - 'A')][(int)('K' - 'A')] = 0.208592169;	P1_disordered[(int)('M' - 'A')][(int)('I' - 'A')] = 0.03296477;	P1_disordered[(int)('M' - 'A')][(int)('E' - 'A')] = 0.19639768;	P1_disordered[(int)('M' - 'A')][(int)('N' - 'A')] = 0.11152659;	P1_disordered[(int)('M' - 'A')][(int)('T' - 'A')] = 0.091282832;	P1_disordered[(int)('M' - 'A')][(int)('D' - 'A')] = 0.13147181;	P1_disordered[(int)('M' - 'A')][(int)('V' - 'A')] = 0.037927995;	P1_disordered[(int)('M' - 'A')][(int)('A' - 'A')] = 0.080920886;	P1_disordered[(int)('M' - 'A')][(int)('G' - 'A')] = 0.0933671503;	P1_disordered[(int)('M' - 'A')][(int)('R' - 'A')] = 0.106875;	P1_disordered[(int)('M' - 'A')][(int)('F' - 'A')] = -0.3634823104;	P1_disordered[(int)('M' - 'A')][(int)('P' - 'A')] = 0.06268305;	P1_disordered[(int)('M' - 'A')][(int)('Q' - 'A')] = 0.101745823;	P1_disordered[(int)('M' - 'A')][(int)('Y' - 'A')] = -0.8874167748;	P1_disordered[(int)('M' - 'A')][(int)('H' - 'A')] = -0.052706302;	P1_disordered[(int)('M' - 'A')][(int)('M' - 'A')] = 0.020035509;	P1_disordered[(int)('M' - 'A')][(int)('C' - 'A')] = -0.0256987985;	P1_disordered[(int)('M' - 'A')][(int)('W' - 'A')] = 0.001054301;
	P1_disordered[(int)('C' - 'A')][(int)('L' - 'A')] = -0.037980827;	P1_disordered[(int)('C' - 'A')][(int)('S' - 'A')] = -0.12157484;	P1_disordered[(int)('C' - 'A')][(int)('K' - 'A')] = -0.093293169;	P1_disordered[(int)('C' - 'A')][(int)('I' - 'A')] = -0.0445485;	P1_disordered[(int)('C' - 'A')][(int)('E' - 'A')] = -0.09048419;	P1_disordered[(int)('C' - 'A')][(int)('N' - 'A')] = -0.0855069;	P1_disordered[(int)('C' - 'A')][(int)('T' - 'A')] = -0.067943015;	P1_disordered[(int)('C' - 'A')][(int)('D' - 'A')] = -0.07377529;	P1_disordered[(int)('C' - 'A')][(int)('V' - 'A')] = -0.040826755;	P1_disordered[(int)('C' - 'A')][(int)('A' - 'A')] = -0.058379276;	P1_disordered[(int)('C' - 'A')][(int)('G' - 'A')] = -0.0479910364;	P1_disordered[(int)('C' - 'A')][(int)('R' - 'A')] = -0.04472141;	P1_disordered[(int)('C' - 'A')][(int)('F' - 'A')] = -0.0188007093;	P1_disordered[(int)('C' - 'A')][(int)('P' - 'A')] = -0.05521014;	P1_disordered[(int)('C' - 'A')][(int)('Q' - 'A')] = -0.052494577;	P1_disordered[(int)('C' - 'A')][(int)('Y' - 'A')] = -0.0177461475;	P1_disordered[(int)('C' - 'A')][(int)('H' - 'A')] = -0.022146681;	P1_disordered[(int)('C' - 'A')][(int)('M' - 'A')] = -0.020755963;	P1_disordered[(int)('C' - 'A')][(int)('C' - 'A')] = -0.0025223962;	P1_disordered[(int)('C' - 'A')][(int)('W' - 'A')] = 0.9967018;
	P1_disordered[(int)('W' - 'A')][(int)('L' - 'A')] = -0.29838543;	P1_disordered[(int)('W' - 'A')][(int)('S' - 'A')] = -0.55245128;	P1_disordered[(int)('W' - 'A')][(int)('K' - 'A')] = -0.394628043;	P1_disordered[(int)('W' - 'A')][(int)('I' - 'A')] = -0.19685156;	P1_disordered[(int)('W' - 'A')][(int)('E' - 'A')] = -0.35797114;	P1_disordered[(int)('W' - 'A')][(int)('N' - 'A')] = -0.35239494;	P1_disordered[(int)('W' - 'A')][(int)('T' - 'A')] = -0.288168605;	P1_disordered[(int)('W' - 'A')][(int)('D' - 'A')] = -0.29013673;	P1_disordered[(int)('W' - 'A')][(int)('V' - 'A')] = -0.179633513;	P1_disordered[(int)('W' - 'A')][(int)('A' - 'A')] = -0.244999777;	P1_disordered[(int)('W' - 'A')][(int)('G' - 'A')] = -0.2016535257;	P1_disordered[(int)('W' - 'A')][(int)('R' - 'A')] = -0.22056541;	P1_disordered[(int)('W' - 'A')][(int)('F' - 'A')] = -0.1129659559;	P1_disordered[(int)('W' - 'A')][(int)('P' - 'A')] = -0.23956874;	P1_disordered[(int)('W' - 'A')][(int)('Q' - 'A')] = -0.227093444;	P1_disordered[(int)('W' - 'A')][(int)('Y' - 'A')] = -0.0906986381;	P1_disordered[(int)('W' - 'A')][(int)('H' - 'A')] = -0.094005667;	P1_disordered[(int)('W' - 'A')][(int)('M' - 'A')] = -0.0963232784;	P1_disordered[(int)('W' - 'A')][(int)('C' - 'A')] = -0.0187290752;	P1_disordered[(int)('W' - 'A')][(int)('W' - 'A')] = -0.01491121;

	disordered_sum_letters[(int)('L' - 'A')] = 0.066721015015535;
	disordered_sum_letters[(int)('S' - 'A')] = 0.123531873142296;
	disordered_sum_letters[(int)('K' - 'A')] = 0.0882415182908647;
	disordered_sum_letters[(int)('I' - 'A')] = 0.0440173529949307;
	disordered_sum_letters[(int)('E' - 'A')] = 0.0800447772679614;
	disordered_sum_letters[(int)('N' - 'A')] = 0.0787978914764474;
	disordered_sum_letters[(int)('T' - 'A')] = 0.064436460527708;
	disordered_sum_letters[(int)('D' - 'A')] = 0.0648765378658894;
	disordered_sum_letters[(int)('V' - 'A')] = 0.0401672774843929;
	disordered_sum_letters[(int)('A' - 'A')] = 0.0547836166180898;
	disordered_sum_letters[(int)('G' - 'A')] = 0.0450910936042094;
	disordered_sum_letters[(int)('R' - 'A')] = 0.0493199242008869;
	disordered_sum_letters[(int)('F' - 'A')] = 0.0252599582527727;
	disordered_sum_letters[(int)('P' - 'A')] = 0.053569195548245;
	disordered_sum_letters[(int)('Q' - 'A')] = 0.0507796342788984;
	disordered_sum_letters[(int)('Y' - 'A')] = 0.0202808318664089;
	disordered_sum_letters[(int)('H' - 'A')] = 0.0210203060822055;
	disordered_sum_letters[(int)('M' - 'A')] = 0.0215385392318125;
	disordered_sum_letters[(int)('C' - 'A')] = 0.00418794909531642;
	disordered_sum_letters[(int)('W' - 'A')] = 0.00333424715512846;

	
	structured_sum_letters[(int)('L' - 'A')] = 0.109750818225155;
	structured_sum_letters[(int)('S' - 'A')] = 0.0733238666830621;
	structured_sum_letters[(int)('K' - 'A')] = 0.0683075527136889;
	structured_sum_letters[(int)('I' - 'A')] = 0.0753255634930929;
	structured_sum_letters[(int)('E' - 'A')] = 0.0605787009352669;
	structured_sum_letters[(int)('N' - 'A')] = 0.0542159440625405;
	structured_sum_letters[(int)('T' - 'A')] = 0.0540766955887993;
	structured_sum_letters[(int)('D' - 'A')] = 0.057005966909397;
	structured_sum_letters[(int)('V' - 'A')] = 0.062555130885143;
	structured_sum_letters[(int)('A' - 'A')] = 0.0543652992803437;
	structured_sum_letters[(int)('G' - 'A')] = 0.0516100885519226;
	structured_sum_letters[(int)('R' - 'A')] = 0.0424354108868724;
	structured_sum_letters[(int)('F' - 'A')] = 0.0528930835619984;
	structured_sum_letters[(int)('P' - 'A')] = 0.0384904117880571;
	structured_sum_letters[(int)('Q' - 'A')] = 0.0350664714942091;
	structured_sum_letters[(int)('Y' - 'A')] = 0.0388615538894401;
	structured_sum_letters[(int)('H' - 'A')] = 0.0215520702261496;
	structured_sum_letters[(int)('M' - 'A')] = 0.020246054299044;
	structured_sum_letters[(int)('C' - 'A')] = 0.0160152589375903;
	structured_sum_letters[(int)('W' - 'A')] = 0.0133240575882277;

	//######################################################################
	// Populate substitution matrix for the gap model
	// We will hardcode the matrix instead.
	//######################################################################
	
	lambda_gap[((int)('X' - 88)/-43)] = -0.002402885;
	lambda_gap[((int)('-' - 88)/-43)] = 0;
	
	P_gap[((int)('X' - 88)/-43)][((int)('X' - 88)/-43)] = -0.7071;
	P_gap[((int)('X' - 88)/-43)][((int)('-' - 88)/-43)] = 0.7071;
	P_gap[((int)('-' - 88)/-43)][((int)('X' - 88)/-43)] = 0.7071;
	P_gap[((int)('-' - 88)/-43)][((int)('-' - 88)/-43)] = 0.7071;
	
	P1_gap[((int)('X' - 88)/-43)][((int)('X' - 88)/-43)] = -0.7071;
	P1_gap[((int)('X' - 88)/-43)][((int)('-' - 88)/-43)] = 0.7071;
	P1_gap[((int)('-' - 88)/-43)][((int)('X' - 88)/-43)] = 0.7071;
	P1_gap[((int)('-' - 88)/-43)][((int)('-' - 88)/-43)] = 0.7071;
	
	double * sum_letters_gap;
	sum_letters_gap = new double[2];
	
	sum_letters_gap[((int)('X' - 88)/-43)] = 0.98219083;
	sum_letters_gap[((int)('-' - 88)/-43)] = 0.01780917;
	
	//######################################################################
	// Populate ancestral sequence
	//######################################################################
	//for(int i = 0;i < sim_length;++i){
	//	distance_dist[i] = 1;	
	//}
	/* initialize random seed: */
	srand ( time(NULL) + seed);
	
	if(ancestral_flag == 1){
		cout << ancestral << endl;
		cout << endl;
		return 0;
	}
	//cout << ancestral << endl;
	//cout << endl;
	// Add ancestral to node.
	nodes.setSequenceOfNode(nodes.getNodeListSize()-1,ancestral);
	nodes.setRateOfNode(nodes.getNodeListSize()-1,distance_dist,sim_length);
	nodes.setGapRateOfNode(nodes.getNodeListSize()-1,gap_dist,sim_length);
	nodes.setDisordered(nodes.getNodeListSize()-1,disordered_ancestral);
	nodes.setPhylo(nodes.getNodeListSize()-1,phylo_hmm_pred);

	// Rate of evolution of the ancestral is distance_dist[pos];


	int child_1;
	int child_2;
	double distance_1;
	double distance_1_at_pos;
	double distance_2;
	double distance_2_at_pos;

	double distance_1_gap_at_pos;
	double distance_2_gap_at_pos;

	for(int i = nodes.getNodeListSize()-1;i >= 0; --i){
		// We now bifurcate down.
		if(nodes.getNodeByID(i).isParent() == 1){

			child_1 = nodes.getNodeByID(i).getChild_1();
			child_2 = nodes.getNodeByID(i).getChild_2();
			distance_1 = nodes.getNodeByID(i).getDistance_1();
			distance_2 = nodes.getNodeByID(i).getDistance_2();

			double * temp_rate_array_1;
			temp_rate_array_1 = new double[nodes.getNodeByID(i).getSequence().length()*2];
			double * temp_rate_array_2;
			temp_rate_array_2 = new double[nodes.getNodeByID(i).getSequence().length()*2];

			double * temp_gap_rate_array_1;
			temp_gap_rate_array_1 = new double[nodes.getNodeByID(i).getSequence().length()*2];
			double * temp_gap_rate_array_2;
			temp_gap_rate_array_2 = new double[nodes.getNodeByID(i).getSequence().length()*2];
			
			string child_1_seq;
			string child_1_disordered_seq;
			string child_1_phylo;
			int child_1_curr_size = 0;

			for(int j = 0;j<nodes.getNodeByID(i).getSequence().length();++j){
				distance_1_at_pos = distance_1 * nodes.getNodeByID(i).getRateAtPos(j);
				
				if(gapcap == 1 && nodes.getNodeByID(i).getDisordered()[j] == '0'){
					distance_1_gap_at_pos = distance_1 * nodes.getNodeByID(i).getGapRateAtPos(j);				
				}
				else{
					distance_1_gap_at_pos = distance_1_at_pos;
				}
				double p_temp1 = 0;
				
				char current_letter = nodes.getNodeByID(i).getSequence()[j];
				char curr_let;
				if(current_letter == '-'){
					curr_let = '-';
				}
				else{
					curr_let = 'X';	
				}
				
				sub_matrix_gap('X','-',distance_1_gap_at_pos,&p_temp1);
				
				// Child 1
				// Deletion or insertion roll
				double random;
				random = (double)rand()/RAND_MAX;
				if(random < p_temp1 && conserved != 1 && nodes.getNodeByID(i).getPhylo()[j] != '1'){
					// Then gap	
					// Determine gap size
					double random2 = (double)rand()/RAND_MAX;
					while(random2 == 1){
						random2 = (double)rand()/RAND_MAX;
					}
					
					double rand_sum = 0.0;
					int k = 1;
					while(rand_sum < random2){
						rand_sum += (double)(pow((double)k,-1.5)/2.612);
						if(rand_sum < random2){
							++k;	
						}
						else{
							break;	
						}
					}
					if(k > 20){
						k = 20;	
					}
					// Determine insertion or deletion
					double random3;
					random3 = (double)rand()/RAND_MAX;
					if(random3 < 0.5){
						// Insertion
					
						if(nodes.getNodeByID(i).getDisordered()[j] == '1'){
							child_1_seq += randomized(k,disordered_sum_letters);
							child_1_disordered_seq += string(k,'1'); 
						}
						else{
							child_1_seq += randomized(k,structured_sum_letters);
							child_1_disordered_seq += string(k,'0');
						}
						child_1_phylo += string(k,nodes.getNodeByID(i).getPhylo()[j]);
						if(gapcap == 1){
							for(int l = 0;l < k;++l){
								temp_rate_array_1[child_1_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
								temp_gap_rate_array_1[child_1_curr_size + l] = nodes.getNodeByID(i).getGapRateAtPos(j);

							}
						}
						else{
							for(int l = 0;l < k;++l){
								temp_rate_array_1[child_1_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
								temp_gap_rate_array_1[child_1_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
							}
						}
						child_1_curr_size += k;
					}
					else{
						// deletion
						// Do not allow deletion of phyloHMM predictions
						for(int l = 1;l < k;++l){
							if(j + l < nodes.getNodeByID(i).getSequence().length()){
								if(nodes.getNodeByID(i).getPhylo()[j + l] == '1'){
									k = l;
									break;
								}
							}
						}
						//child_1_curr_size -= k;
						j = j + k -1;
					}
				}		
				else{
					// Then amino acid substitution model	
					double random2;
					random2 = (double)rand()/RAND_MAX;
					while(random2 == 1){
						random2 = (double)rand()/RAND_MAX;
					}

					double rand_sum = 0;
					
					for(int k = 0;k < aalist_size;++k){
						rand_sum += sub_matrix3(current_letter,aalist[k][0],distance_1_at_pos,nodes.getNodeByID(i).getDisordered()[j]);
						
						if(rand_sum > random2){
							child_1_seq += aalist[k];
							child_1_disordered_seq += nodes.getNodeByID(i).getDisordered()[j];
							child_1_phylo += nodes.getNodeByID(i).getPhylo()[j];
							temp_rate_array_1[child_1_curr_size] = nodes.getNodeByID(i).getRateAtPos(j);
							if(gapcap == 1){
								temp_gap_rate_array_1[child_1_curr_size] = nodes.getNodeByID(i).getGapRateAtPos(j);
							}
							else{
								temp_gap_rate_array_1[child_1_curr_size] = nodes.getNodeByID(i).getRateAtPos(j);
							}
							child_1_curr_size += 1;
							break;
						}
					}
				}
			}
			
			string child_2_seq;
			string child_2_disordered_seq;
			string child_2_phylo;
			int child_2_curr_size = 0;
			for(int j = 0;j<nodes.getNodeByID(i).getSequence().length();++j){
				distance_2_at_pos = distance_2 * nodes.getNodeByID(i).getRateAtPos(j);
				
				if(gapcap == 1  && nodes.getNodeByID(i).getDisordered()[j] == '0'){
					distance_2_gap_at_pos = distance_2 * nodes.getNodeByID(i).getGapRateAtPos(j);
				}
				else{
					distance_2_gap_at_pos = distance_2_at_pos;
				}

				double p_temp1 = 0;
				
				char current_letter = nodes.getNodeByID(i).getSequence()[j];
				char curr_let;
				if(current_letter == '-'){
					curr_let = '-';
				}
				else{
					curr_let = 'X';	
				}
				
				sub_matrix_gap('X','-',distance_2_gap_at_pos,&p_temp1);
				
				// Child 2
				// Deletion or insertion roll
				double random;
				random = (double)rand()/RAND_MAX;
				if(random < p_temp1 && conserved != 1 && nodes.getNodeByID(i).getPhylo()[j] != '1'){
					// Then gap	
					// Determine gap size
					double random2 = (double)rand()/RAND_MAX;
					while(random2 == 1){
						random2 = (double)rand()/RAND_MAX;
					}
					
					double rand_sum = 0.0;
					int k = 1;
					while(rand_sum < random2){
						rand_sum += (double)(pow((double)k,-1.5)/2.612);
						if(rand_sum < random2){
							++k;	
						}
						else{
							break;	
						}
					}
					if(k > 20){
						k = 20;	
					}
					// Determine insertion or deletion
					double random3;
					random3 = (double)rand()/RAND_MAX;
					if(random3 < 0.5){
						// Insertion
						if(nodes.getNodeByID(i).getDisordered()[j] == '1'){
							child_2_seq += randomized(k,disordered_sum_letters);
							child_2_disordered_seq += string(k,'1');
						}
						else{
							child_2_seq += randomized(k,structured_sum_letters);
							child_2_disordered_seq += string(k,'0');
						}
						child_2_phylo += string(k,nodes.getNodeByID(i).getPhylo()[j]);
						
						if(gapcap == 1){
							for(int l = 0;l < k;++l){
								temp_rate_array_2[child_2_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
								temp_gap_rate_array_2[child_2_curr_size + l] = nodes.getNodeByID(i).getGapRateAtPos(j);

							}
						}
						else{
							for(int l = 0;l < k;++l){
								temp_rate_array_2[child_2_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
								temp_gap_rate_array_2[child_2_curr_size + l] = nodes.getNodeByID(i).getRateAtPos(j);
							}
						}
						child_2_curr_size += k;
					}
					else{
						// deletion
						// Do not allow deletion of phyloHMM predictions
						for(int l = 1;l < k;++l){
							if(j + l < nodes.getNodeByID(i).getSequence().length()){
								if(nodes.getNodeByID(i).getPhylo()[j + l] == '1'){
									k = l;
									break;
								}
							}
						}
						j = j + k -1;
						//child_2_curr_size -= k;
					}
				}		
				else{
					// Then amino acid substitution model	
					double random2;
					random2 = (double)rand()/RAND_MAX;
					while(random2 == 1){
						random2 = (double)rand()/RAND_MAX;
					}


					double rand_sum = 0;
					
					for(int k = 0;k < aalist_size;++k){
						rand_sum += sub_matrix3(current_letter,aalist[k][0],distance_2_at_pos,nodes.getNodeByID(i).getDisordered()[j]);
						
						if(rand_sum > random2){
							child_2_seq += aalist[k];	
							child_2_disordered_seq += nodes.getNodeByID(i).getDisordered()[j];
							child_2_phylo += nodes.getNodeByID(i).getPhylo()[j];
							temp_rate_array_2[child_2_curr_size] = nodes.getNodeByID(i).getRateAtPos(j);
							if(gapcap == 1){
								temp_gap_rate_array_2[child_2_curr_size] = nodes.getNodeByID(i).getGapRateAtPos(j);
							}
							else{
								temp_gap_rate_array_2[child_2_curr_size] = nodes.getNodeByID(i).getRateAtPos(j);
							}
							child_2_curr_size += 1;
							break;
						}
					}
					
				}
			}
			
			nodes.setSequenceOfNode(child_1,child_1_seq);
			nodes.setSequenceOfNode(child_2,child_2_seq);	
			nodes.setRateOfNode(child_1,temp_rate_array_1,child_1_seq.length());
			nodes.setRateOfNode(child_2,temp_rate_array_2,child_2_seq.length());	
			nodes.setGapRateOfNode(child_1,temp_gap_rate_array_1,child_1_seq.length());
			nodes.setGapRateOfNode(child_2,temp_gap_rate_array_2,child_2_seq.length());	
			nodes.setDisordered(child_1,child_1_disordered_seq);
			nodes.setDisordered(child_2,child_2_disordered_seq);
			nodes.setPhylo(child_1,child_1_phylo);
			nodes.setPhylo(child_2,child_2_phylo);

			delete [] temp_rate_array_1;
			delete [] temp_rate_array_2;
			delete [] temp_gap_rate_array_1;
			delete [] temp_gap_rate_array_2;
					
		}
					
	}
	
	for(int i = 0;i < nodes.getNodeListSize(); ++i){
		if(nodes.getNodeByID(i).isParent() == 0){
			cout << ">" << nodes.getNodeByID(i).getSpecie() << endl;
			cout << nodes.getNodeByID(i).getSequence() << endl;
		}
	}
	
}
	
